<?php
// admin/invite-employee.php
require_once __DIR__ . '/../helpers/InvitationHelper.php';

// Require admin access
// Require admin or owner access
AuthHelper::requireAdminOrOwner($pdo);


$error = '';
$success = '';
$organizationId = $_SESSION['organization_id'];
$userId = $_SESSION['user_id'];

// Get organization info
$orgName = InvitationHelper::getOrganizationName($organizationId, $pdo);
$adminName = InvitationHelper::getUserName($userId, $pdo);

// Handle form submission
if ($_SERVER['REQUEST_METHOD'] === 'POST') {
    $email = filter_var(trim($_POST['email'] ?? ''), FILTER_VALIDATE_EMAIL);
    $firstName = trim($_POST['first_name'] ?? '');
    $lastName = trim($_POST['last_name'] ?? '');
    $role = $_POST['role'] ?? 'user';
    
    // Validation
    if (!$email) {
        $error = "Please enter a valid email address.";
    } elseif (!in_array($role, ['user', 'admin'])) {
        $error = "Please select a valid role.";
    } else {
        // Check if email is already invited or registered
        $emailCheck = InvitationHelper::isEmailAlreadyInvited($email, $organizationId, $pdo);
        
        if ($emailCheck === 'user_exists') {
            $error = "This email address is already registered as a user in your organization.";
        } elseif ($emailCheck === 'pending_invitation') {
            $error = "This email address already has a pending invitation. Please wait for them to accept or cancel the existing invitation.";
        } else {
            try {
                $pdo->beginTransaction();
                
                // Generate invitation token
                $token = InvitationHelper::generateInvitationToken();
                $expiresAt = date('Y-m-d H:i:s', strtotime('+7 days'));
                
                // Insert invitation
                $stmt = $pdo->prepare("
                    INSERT INTO whsale_inventory_pro_invitations 
                    (organization_id, email, first_name, last_name, role, invitation_token, invited_by, expires_at) 
                    VALUES (?, ?, ?, ?, ?, ?, ?, ?)
                ");
                $stmt->execute([
                    $organizationId, 
                    $email, 
                    $firstName ?: null, 
                    $lastName ?: null, 
                    $role, 
                    $token, 
                    $userId, 
                    $expiresAt
                ]);
                
                // Send invitation email
                $emailSent = InvitationHelper::sendInvitationEmail(
                    $email, 
                    $firstName, 
                    $lastName, 
                    $orgName, 
                    $adminName, 
                    $token
                );
                
                if ($emailSent) {
                    $pdo->commit();
                    $success = "Invitation sent successfully to " . htmlspecialchars($email) . "!";
                    
                    // Clear form
                    $_POST = [];
                } else {
                    $pdo->rollback();
                    $error = "Failed to send invitation email. Please try again.";
                }
                
            } catch (Exception $e) {
                $pdo->rollback();
                $error = "Failed to send invitation: " . $e->getMessage();
            }
        }
    }
}

// Get pending invitations
$pendingInvitations = [];
try {
    $stmt = $pdo->prepare("
        SELECT i.*, u.first_name as invited_by_first_name, u.last_name as invited_by_last_name
        FROM whsale_inventory_pro_invitations i
        LEFT JOIN whsale_inventory_pro_users u ON i.invited_by = u.id
        WHERE i.organization_id = ? AND i.status = 'pending' AND i.expires_at > NOW()
        ORDER BY i.invited_at DESC
    ");
    $stmt->execute([$organizationId]);
    $pendingInvitations = $stmt->fetchAll(PDO::FETCH_ASSOC);
} catch (Exception $e) {
    error_log("Error fetching pending invitations: " . $e->getMessage());
}
?>

<?php include __DIR__ . '/../views/partials/head.php'; ?>

<div class="container mt-4 mb-5">
    <div class="d-flex justify-content-between align-items-center mb-4">
        <h4>Invite Employee</h4>
        <a href="<?= BASE_URL ?>admin/manage-users" class="btn btn-outline-secondary">
            <i class="fas fa-users me-1"></i>Manage Users
        </a>
    </div>

    <?php if ($error): ?>
        <div class="alert alert-danger">
            <i class="fas fa-exclamation-circle me-2"></i><?= htmlspecialchars($error) ?>
        </div>
    <?php endif; ?>

    <?php if ($success): ?>
        <div class="alert alert-success">
            <i class="fas fa-check-circle me-2"></i><?= htmlspecialchars($success) ?>
        </div>
    <?php endif; ?>

    <div class="row">
        <!-- Invitation Form -->
        <div class="col-lg-6">
            <div class="card shadow-sm border-0">
                <div class="card-header bg-primary text-white">
                    <h6 class="mb-0">
                        <i class="fas fa-user-plus me-2"></i>Send Invitation
                    </h6>
                </div>
                <div class="card-body">
                    <form method="POST">
                        <div class="mb-3">
                            <label for="email" class="form-label">Email Address <span class="text-danger">*</span></label>
                            <input type="email" class="form-control" id="email" name="email" 
                                   value="<?= htmlspecialchars($_POST['email'] ?? '') ?>" required>
                            <div class="form-text">The employee will receive an invitation at this email address.</div>
                        </div>

                        <div class="row">
                            <div class="col-md-6 mb-3">
                                <label for="firstName" class="form-label">First Name</label>
                                <input type="text" class="form-control" id="firstName" name="first_name" 
                                       value="<?= htmlspecialchars($_POST['first_name'] ?? '') ?>" maxlength="100">
                                <div class="form-text">Optional - they can set this later</div>
                            </div>
                            <div class="col-md-6 mb-3">
                                <label for="lastName" class="form-label">Last Name</label>
                                <input type="text" class="form-control" id="lastName" name="last_name" 
                                       value="<?= htmlspecialchars($_POST['last_name'] ?? '') ?>" maxlength="100">
                                <div class="form-text">Optional - they can set this later</div>
                            </div>
                        </div>

                        <div class="mb-3">
                            <label for="role" class="form-label">Role <span class="text-danger">*</span></label>
                            <select class="form-select" id="role" name="role" required>
                                <option value="admin">Employee - Customizable permissions based on role</option>
                            </select>
                        </div>

                        <div class="d-grid">
                            <button type="submit" class="btn btn-primary">
                                <i class="fas fa-paper-plane me-1"></i>Send Invitation
                            </button>
                        </div>
                    </form>
                </div>
            </div>
        </div>

        <!-- Pending Invitations -->
        <div class="col-lg-6">
            <div class="card shadow-sm border-0">
                <div class="card-header bg-secondary text-white">
                    <h6 class="mb-0">
                        <i class="fas fa-clock me-2"></i>Pending Invitations
                        <span class="badge bg-light text-dark ms-2"><?= count($pendingInvitations) ?></span>
                    </h6>
                </div>
                <div class="card-body">
                    <?php if (empty($pendingInvitations)): ?>
                        <div class="text-center text-muted py-4">
                            <i class="fas fa-inbox fa-2x mb-3"></i>
                            <p>No pending invitations</p>
                        </div>
                    <?php else: ?>
                        <div class="list-group list-group-flush">
                            <?php foreach ($pendingInvitations as $invitation): ?>
                                <div class="list-group-item d-flex justify-content-between align-items-start">
                                    <div class="flex-grow-1">
                                        <h6 class="mb-1"><?= htmlspecialchars($invitation['email']) ?></h6>
                                        <?php if ($invitation['first_name'] || $invitation['last_name']): ?>
                                            <p class="mb-1 text-muted small">
                                                <?= htmlspecialchars(trim($invitation['first_name'] . ' ' . $invitation['last_name'])) ?>
                                            </p>
                                        <?php endif; ?>
                                        <small class="text-muted">
                                            <i class="fas fa-user-tag me-1"></i><?= ucfirst($invitation['role']) ?> •
                                            <i class="fas fa-calendar me-1"></i>Expires <?= date('M j, Y', strtotime($invitation['expires_at'])) ?>
                                        </small>
                                    </div>
                                    <div class="dropdown">
                                        <button class="btn btn-sm btn-outline-secondary dropdown-toggle" type="button" 
                                                data-bs-toggle="dropdown">
                                            <i class="fas fa-ellipsis-v"></i>
                                        </button>
                                        <ul class="dropdown-menu dropdown-menu-end">
                                            <li>
                                                <a class="dropdown-item" href="#" 
                                                   onclick="resendInvitation(<?= $invitation['id'] ?>)">
                                                    <i class="fas fa-redo me-2"></i>Resend
                                                </a>
                                            </li>
                                            <li>
                                                <a class="dropdown-item text-danger" href="#" 
                                                   onclick="cancelInvitation(<?= $invitation['id'] ?>)">
                                                    <i class="fas fa-times me-2"></i>Cancel
                                                </a>
                                            </li>
                                        </ul>
                                    </div>
                                </div>
                            <?php endforeach; ?>
                        </div>
                    <?php endif; ?>
                </div>
            </div>
        </div>
    </div>
</div>

<script>
function resendInvitation(invitationId) {
    if (confirm('Resend invitation email?')) {
        fetch('<?= BASE_URL ?>admin/resend-invitation', {
            method: 'POST',
            headers: { 'Content-Type': 'application/x-www-form-urlencoded' },
            body: `invitation_id=${invitationId}`
        })
        .then(response => response.json())
        .then(data => {
            if (data.success) {
                alert('Invitation resent successfully!');
            } else {
                alert('Failed to resend invitation: ' + data.message);
            }
        })
        .catch(error => {
            alert('Error: ' + error.message);
        });
    }
}

function cancelInvitation(invitationId) {
    if (confirm('Cancel this invitation? The user will no longer be able to use this invitation link.')) {
        fetch('<?= BASE_URL ?>admin/cancel-invitation', {
            method: 'POST',
            headers: { 'Content-Type': 'application/x-www-form-urlencoded' },
            body: `invitation_id=${invitationId}`
        })
        .then(response => response.json())
        .then(data => {
            if (data.success) {
                location.reload();
            } else {
                alert('Failed to cancel invitation: ' + data.message);
            }
        })
        .catch(error => {
            alert('Error: ' + error.message);
        });
    }
}
</script>

<?php include __DIR__ . '/../views/partials/footer.php'; ?>