<?php
// admin/resend-invitation.php
require_once __DIR__ . '/../helpers/InvitationHelper.php';

// Set proper JSON header immediately
header('Content-Type: application/json');

// Disable any output buffering that might add whitespace
while (ob_get_level()) {
    ob_end_clean();
}

try {
    // Require admin access
    InvitationHelper::requireAdmin($pdo);
} catch (Exception $e) {
    echo json_encode(['success' => false, 'message' => 'Access denied']);
    exit;
}

if ($_SERVER['REQUEST_METHOD'] !== 'POST') {
    echo json_encode(['success' => false, 'message' => 'Invalid request method']);
    exit;
}

$invitationId = $_POST['invitation_id'] ?? null;
$organizationId = $_SESSION['organization_id'];
$userId = $_SESSION['user_id'];

if (!$invitationId || !is_numeric($invitationId)) {
    echo json_encode(['success' => false, 'message' => 'Invalid invitation ID']);
    exit;
}

try {
    // Get invitation details
    $stmt = $pdo->prepare("
        SELECT * FROM whsale_inventory_pro_invitations 
        WHERE id = ? AND organization_id = ? AND status = 'pending'
    ");
    $stmt->execute([$invitationId, $organizationId]);
    $invitation = $stmt->fetch(PDO::FETCH_ASSOC);
    
    if (!$invitation) {
        echo json_encode(['success' => false, 'message' => 'Invitation not found or already processed']);
        exit;
    }
    
    // Generate new token and extend expiry
    $newToken = InvitationHelper::generateInvitationToken();
    $newExpiry = date('Y-m-d H:i:s', strtotime('+7 days'));
    
    // Update invitation
    $stmt = $pdo->prepare("
        UPDATE whsale_inventory_pro_invitations 
        SET invitation_token = ?, expires_at = ?, updated_at = NOW() 
        WHERE id = ?
    ");
    $stmt->execute([$newToken, $newExpiry, $invitationId]);
    
    // Get organization and admin info
    $orgName = InvitationHelper::getOrganizationName($organizationId, $pdo);
    $adminName = InvitationHelper::getUserName($userId, $pdo);
    
    // Send new invitation email
    $emailSent = InvitationHelper::sendInvitationEmail(
        $invitation['email'],
        $invitation['first_name'],
        $invitation['last_name'],
        $orgName,
        $adminName,
        $newToken
    );
    
    if ($emailSent) {
        echo json_encode(['success' => true, 'message' => 'Invitation resent successfully']);
    } else {
        echo json_encode(['success' => false, 'message' => 'Failed to send email']);
    }
    
} catch (Exception $e) {
    error_log("Error resending invitation: " . $e->getMessage());
    echo json_encode(['success' => false, 'message' => 'Server error occurred']);
}
?>