<?php
// helpers/InvitationHelper.php

class InvitationHelper {
    
    /**
     * Generate a secure invitation token
     */
    public static function generateInvitationToken() {
        return bin2hex(random_bytes(32));
    }
    
    /**
     * Send invitation email with better configuration
     */
    public static function sendInvitationEmail($email, $firstName, $lastName, $organizationName, $invitedByName, $token) {
        $subject = "You're invited to join " . $organizationName;
        $inviteUrl = BASE_URL . "auth/complete-invitation?token=" . urlencode($token);
        
        // Get the server domain for proper FROM address
        $domain = parse_url(BASE_URL, PHP_URL_HOST);
        $fromEmail = "noreply@" . $domain;
        
        $body = "
        <html>
        <head>
            <style>
                body { font-family: Arial, sans-serif; line-height: 1.6; color: #333; }
                .container { max-width: 600px; margin: 0 auto; padding: 20px; }
                .header { background: #007bff; color: white; padding: 20px; text-align: center; }
                .content { padding: 30px 20px; background: #f8f9fa; }
                .button { display: inline-block; padding: 12px 30px; background: #007bff; color: white; text-decoration: none; border-radius: 5px; margin: 20px 0; }
                .footer { padding: 20px; text-align: center; color: #666; font-size: 12px; }
            </style>
        </head>
        <body>
            <div class='container'>
                <div class='header'>
                    <h2>You're Invited!</h2>
                </div>
                <div class='content'>
                    <p>Hello" . ($firstName ? " " . htmlspecialchars($firstName) : "") . ",</p>
                    
                    <p><strong>" . htmlspecialchars($invitedByName) . "</strong> has invited you to join <strong>" . htmlspecialchars($organizationName) . "</strong>'s inventory management system.</p>
                    
                    <p>To complete your account setup and start managing inventory, please click the button below:</p>
                    
                    <div style='text-align: center;'>
                        <a href='" . $inviteUrl . "' class='button'>Complete Account Setup</a>
                    </div>
                    
                    <p><small>Or copy and paste this link into your browser:<br>
                    <a href='" . $inviteUrl . "'>" . $inviteUrl . "</a></small></p>
                    
                    <p><strong>Important:</strong> This invitation will expire in 7 days for security reasons.</p>
                    
                    <p>If you have any questions, please contact " . htmlspecialchars($invitedByName) . " or your system administrator.</p>
                </div>
                <div class='footer'>
                    <p>This is an automated message. Please do not reply to this email.</p>
                </div>
            </div>
        </body>
        </html>
        ";
        
        // Use proper line endings for mail headers
        $headers = "MIME-Version: 1.0\r\n";
        $headers .= "Content-type: text/html; charset=UTF-8\r\n";
        $headers .= "From: " . (defined('SITE_NAME') ? SITE_NAME : 'Inventory System') . " <" . $fromEmail . ">\r\n";
        $headers .= "Reply-To: " . $fromEmail . "\r\n";
        
        // Add additional parameters for better delivery
        $additionalParams = "-f " . $fromEmail;
        
        // Send email with additional parameters
        $result = mail($email, $subject, $body, $headers, $additionalParams);
        
        // Log email sending attempts for debugging
        error_log("Invitation email attempt: to=$email, result=" . ($result ? 'success' : 'failed'));
        
        return $result;
    }
    
    /**
     * Check if user is admin of their organization
     */
    public static function isAdmin($userId, $pdo) {
        try {
            $stmt = $pdo->prepare("SELECT role FROM whsale_inventory_pro_users WHERE id = ? AND account_status = 'active'");
            $stmt->execute([$userId]);
            $user = $stmt->fetch();
            return $user && $user['role'] === 'admin';
        } catch (Exception $e) {
            error_log("Error checking admin status: " . $e->getMessage());
            return false;
        }
    }
    
    /**
     * Require admin access - redirect if not admin
     */
    public static function requireAdmin($pdo) {
        require_once __DIR__ . '/AuthHelper.php';
        AuthHelper::requireLogin();
        
        if (!self::isAdmin($_SESSION['user_id'], $pdo)) {
            $_SESSION['error'] = "Access denied. Administrator privileges required.";
            header("Location: " . BASE_URL . "dashboard");
            exit;
        }
    }
    
    /**
     * Get organization name by ID - Fixed to use proper table and fallback
     */
    public static function getOrganizationName($organizationId, $pdo) {
        try {
            // Try the main organizations table first
            $stmt = $pdo->prepare("SELECT organization_name FROM whsale_inventory_pro_organizations WHERE id = ?");
            $stmt->execute([$organizationId]);
            $org = $stmt->fetch();
            
            if ($org && !empty($org['organization_name'])) {
                return $org['organization_name'];
            }
            
            // Fallback: try to get from users table if organizations table doesn't exist
            $stmt = $pdo->prepare("
                SELECT DISTINCT organization_slug as name 
                FROM whsale_inventory_pro_users 
                WHERE organization_id = ? 
                LIMIT 1
            ");
            $stmt->execute([$organizationId]);
            $user = $stmt->fetch();
            
            if ($user && !empty($user['name'])) {
                return ucfirst(str_replace(['_', '-'], ' ', $user['name']));
            }
            
            return 'Your Organization';
        } catch (Exception $e) {
            error_log("Error getting organization name: " . $e->getMessage());
            return 'Your Organization';
        }
    }
    
    /**
     * Get user's full name by ID
     */
    public static function getUserName($userId, $pdo) {
        try {
            $stmt = $pdo->prepare("SELECT first_name, last_name FROM whsale_inventory_pro_users WHERE id = ?");
            $stmt->execute([$userId]);
            $user = $stmt->fetch();
            if ($user) {
                $fullName = trim($user['first_name'] . ' ' . $user['last_name']);
                return !empty($fullName) ? $fullName : 'System Administrator';
            }
            return 'System Administrator';
        } catch (Exception $e) {
            error_log("Error getting user name: " . $e->getMessage());
            return 'System Administrator';
        }
    }
    
    /**
     * Validate invitation token - Fixed SQL syntax and error handling
     */
    public static function validateInvitationToken($token, $pdo) {
        try {
            // First check the invitations table - FIXED SQL SYNTAX
            $stmt = $pdo->prepare("
                SELECT i.*, 
                       COALESCE(o.organization_slug, 'Your Organization') as organization_name 
                FROM whsale_inventory_pro_invitations i
                LEFT JOIN whsale_inventory_pro_organizations o ON i.organization_id = o.id
                WHERE i.invitation_token = ? 
                AND i.status = 'pending' 
                AND i.expires_at > NOW()
            ");
            $stmt->execute([$token]);
            $invitation = $stmt->fetch(PDO::FETCH_ASSOC);
            
            if ($invitation) {
                error_log("Token validation SUCCESS for: " . $invitation['email']);
                return $invitation;
            }
            
            // Also check if token exists but expired/used for better error messages
            $stmt = $pdo->prepare("
                SELECT i.status, i.expires_at, i.email
                FROM whsale_inventory_pro_invitations i
                WHERE i.invitation_token = ?
            ");
            $stmt->execute([$token]);
            $expiredInvitation = $stmt->fetch(PDO::FETCH_ASSOC);
            
            if ($expiredInvitation) {
                if ($expiredInvitation['status'] !== 'pending') {
                    error_log("Token validation FAILED - already used: email=" . $expiredInvitation['email'] . ", status=" . $expiredInvitation['status']);
                } else {
                    error_log("Token validation FAILED - expired: email=" . $expiredInvitation['email'] . ", expires_at=" . $expiredInvitation['expires_at']);
                }
            } else {
                error_log("Token validation FAILED - not found in database: " . substr($token, 0, 10) . "...");
            }
            
            return false;
        } catch (Exception $e) {
            error_log("Error validating invitation token: " . $e->getMessage());
            return false;
        }
    }
    
    /**
     * Check if email is already invited or registered
     */
    public static function isEmailAlreadyInvited($email, $organizationId, $pdo) {
        try {
            // Check if already a user
            $stmt = $pdo->prepare("SELECT id FROM whsale_inventory_pro_users WHERE email = ? AND organization_id = ?");
            $stmt->execute([$email, $organizationId]);
            if ($stmt->fetch()) {
                return 'user_exists';
            }
            
            // Check if already invited and pending
            $stmt = $pdo->prepare("
                SELECT id FROM whsale_inventory_pro_invitations 
                WHERE email = ? AND organization_id = ? AND status = 'pending' AND expires_at > NOW()
            ");
            $stmt->execute([$email, $organizationId]);
            if ($stmt->fetch()) {
                return 'pending_invitation';
            }
            
            return false;
        } catch (Exception $e) {
            error_log("Error checking email invitation status: " . $e->getMessage());
            return false;
        }
    }
}