<?php
require_once __DIR__ . '/../config/config.php';
require_once __DIR__ . '/../config/db.php';
require_once __DIR__ . '/../helpers/AuthHelper.php';
require_once __DIR__ . '/../helpers/RoleHelper.php';

AuthHelper::requireLogin();

$userId = $_SESSION['user_id'];
$organizationId = $_SESSION['organization_id']; // Added for organization-based totals

// Total counts - Changed to organization totals instead of user totals
$receivingCountStmt = $pdo->prepare("
    SELECT COUNT(*) AS total
    FROM whsale_inventory_pro_receiving_log
    WHERE organization_id = ?
");
$receivingCountStmt->execute([$organizationId]);
$receivingCount = $receivingCountStmt->fetch()['total'] ?? 0;

// Updated to use the new stored procedure for inventory count
try {
    $inventoryCountStmt = $pdo->prepare("CALL whsale_inventory_pro_get_inventory_items_by_org_id(?)");
    $inventoryCountStmt->execute([$organizationId]);
    $inventoryItems = $inventoryCountStmt->fetchAll();
    $inventoryCount = count($inventoryItems);
    $inventoryCountStmt->closeCursor();
} catch (Exception $e) {
    error_log("Error getting inventory count: " . $e->getMessage());
    $inventoryCount = 0;
}

// UPDATED: Get storefront active listings count for users with permission
$activeListings = 0;
if (RoleHelper::hasPermission('publish_to_storefront')) {
    try {
        $storefrontCountStmt = $pdo->prepare("
            SELECT COUNT(*) AS total
            FROM whsale_inventory_pro_storefront_products
            WHERE organization_id = ? AND is_active = 1
        ");
        $storefrontCountStmt->execute([$organizationId]);
        $activeListings = $storefrontCountStmt->fetch()['total'] ?? 0;
    } catch (Exception $e) {
        error_log("Error getting storefront count: " . $e->getMessage());
        $activeListings = 0;
    }
}

// FIXED - Recent receiving logs for this organization
$recentReceivingStmt = $pdo->prepare("
    SELECT id, vendor_name, created_at
    FROM whsale_inventory_pro_receiving_log
    WHERE organization_id = ?
    ORDER BY created_at DESC
    LIMIT 5
");
$recentReceivingStmt->execute([$organizationId]); // Use organizationId
$recentReceiving = $recentReceivingStmt->fetchAll();

// FIXED - Recent inventory items for this organization  
$recentItemsStmt = $pdo->prepare("
    SELECT id, product_name, sku, created_at
    FROM whsale_inventory_pro_inventory_items
    WHERE organization_id = ?
    ORDER BY created_at DESC
    LIMIT 5
");
$recentItemsStmt->execute([$organizationId]); // Use organizationId
$recentItems = $recentItemsStmt->fetchAll();

// Weekly trend for receiving logs - Changed to organization-wide
$weeklyStatsStmt = $pdo->prepare("
    SELECT DATE(created_at) as day, COUNT(*) as count
    FROM whsale_inventory_pro_receiving_log
    WHERE organization_id = ? AND created_at >= CURDATE() - INTERVAL 6 DAY
    GROUP BY day
    ORDER BY day ASC
");
$weeklyStatsStmt->execute([$organizationId]); // Changed from $userId to $organizationId
$weeklyData = $weeklyStatsStmt->fetchAll(PDO::FETCH_KEY_PAIR);

// Fill in missing days
$trendLabels = [];
$trendCounts = [];
for ($i = 6; $i >= 0; $i--) {
    $day = date('Y-m-d', strtotime("-$i days"));
    $trendLabels[] = date('D', strtotime($day));
    $trendCounts[] = $weeklyData[$day] ?? 0;
}
?>

<?php include __DIR__ . '/partials/head.php'; ?>

<div class="container mt-4 mb-5">
    <div class="d-flex align-items-center mb-3">
        <h4 class="mb-0 me-3">Welcome, <?= htmlspecialchars($_SESSION['first_name']) ?>!</h4>
    </div>
    <p class="text-muted">Here's a quick overview of your activity.</p>

    <div class="row g-4 mt-3">
        <div class="col-md-6">
            <div class="card border-0 shadow-sm bg-light h-100">
                <div class="card-body">
                    <h5 class="card-title">
                        <i class="fas fa-truck me-2"></i>Receiving Logs
                    </h5>
                    <p class="text-muted small">Total receiving logs in your organization</p>
                    <p class="card-text display-6 fw-bold text-primary"><?= $receivingCount ?></p>
                    <div class="d-flex gap-2 flex-wrap">
                        <a href="<?= BASE_URL ?>receiving" class="btn btn-sm btn-outline-primary">View Logs</a>
                        <?php if (RoleHelper::hasPermission('create_receiving_logs')): ?>
                            <a href="<?= BASE_URL ?>receiving/add" class="btn btn-sm btn-outline-success" data-permission="create_receiving_logs">
                                <i class="fas fa-plus me-1"></i>+Add Log
                            </a>
                        <?php endif; ?>
                    </div>
                </div>
            </div>
        </div>
        <div class="col-md-6">
            <div class="card border-0 shadow-sm bg-light h-100">
                <div class="card-body">
                    <h5 class="card-title">
                        <i class="fas fa-boxes me-2"></i>Inventory Items
                    </h5>
                    <p class="text-muted small">Total items in your organization inventory</p>
                    <p class="card-text display-6 fw-bold text-primary"><?= $inventoryCount ?></p>
                    <div class="d-flex gap-2 flex-wrap">
                        <?php if (RoleHelper::hasPermission('view_all_inventory')): ?>
                            <a href="<?= BASE_URL ?>inventory" class="btn btn-sm btn-outline-primary" data-permission="view_all_inventory">Manage Inventory</a>
                        <?php endif; ?>
                        <?php if (RoleHelper::hasPermission('create_receiving_logs')): ?>
                            <a href="<?= BASE_URL ?>receiving" class="btn btn-sm btn-outline-success">
                                <i class="fas fa-plus me-1"></i>+Add Items to a Log
                            </a>
                        <?php endif; ?>
                    </div>
                </div>
            </div>
        </div>
    </div>

<!-- UPDATED: Storefront Access Card with Active Listings Count -->
    <?php if (RoleHelper::hasPermission('publish_to_storefront')): ?>
        <div class="admin-section">
            <div class="row mt-4">
                <div class="col-12">
                    <div class="card border-0 shadow-sm bg-white">
                        <div class="card-body text-center p-4">
                            <h5 class="mb-2">
                                <i class="fas fa-store me-2"></i>Your Storefront
                            </h5>
                            <p class="text-muted mb-3">Manage your product listings and view your live store.</p>
                            
                            <!-- UPDATED: Active listings display -->
                            <div class="mb-3">
                                <span class="badge bg-success fs-6 px-3 py-2">
                                    <i class="fas fa-eye me-1"></i>
                                    <?= $activeListings ?> Active Listing<?= $activeListings !=+ 1 ? 's' : '' ?>
                                </span>
                            </div>
                            
                            <div class="d-grid gap-2 d-sm-flex justify-content-sm-center">
                                <a href="<?= BASE_URL ?>storefront/manage" class="btn btn-outline-success btn-md" data-permission="publish_to_storefront">
                                    <iclass="fas fa-cog me-2"></i>Manage Listings
                                </a>
                                
                                <!-- Updated View Store Button with Device Detection -->
                                <button type="button" class="btn btn-outline-primary btn-md" id="viewStoreBtn"
                                        data-store-url="<?= BASE_URL ?>storefront/<?= urlencode($_SESSION['organization_slug']) ?>">
                                    <iclass="fas fa-external-link-alt me-2"></i>View My Store
                                </button>
                                
                                <!-- UPDATED: Moved Customize button into main action area -->
                                <?php if (RoleHelper::hasPermission('manage_storefront_branding')): ?>
                                    <a href="<?= BASE_URL ?>storefront/profile/edit" 
                                       class="btn btn-outline-secondary btn-md" 
                                       data-permission="manage_storefront_branding">
                                        <iclass="fas fa-palette me-2"></i>Customize Store Branding
                                    </a>
                                <?php endif; ?>
                            </div>
                        </div>
                    </div>
                </div>
            </div>
        </div>
    <?php endif; ?>

    <!-- Weekly Trend Chart -->
    <div class="card mt-5 shadow-sm border-0">
        <div class="card-body">
            <h5 class="card-title mb-3">
                <i class="fas fa-chart-line me-2"></i>Receiving Logs This Week
            </h5>
            <canvas id="weeklyTrendChart" height="100"></canvas>
        </div>
    </div>

    <!-- Recent Activity -->
    <div class="row g-4 mt-4">
        <div class="col-md-6">
            <div class="card shadow-sm border-0 h-100">
                <div class="card-body">
                    <h5 class="card-title">
                        <i class="fas fa-clock me-2"></i>Recent Receiving Logs
                    </h5>
                    <ul class="list-group list-group-flush">
                        <?php foreach ($recentReceiving as $log): ?>
                            <li class="list-group-item small d-flex justify-content-between align-items-center">
                                <div>
                                    <strong><?= htmlspecialchars($log['vendor_name']) ?></strong>
                                    <br><small class="text-muted"><?= date('M d, Y', strtotime($log['created_at'])) ?></small>
                                </div>
                                <a href="<?= BASE_URL ?>receiving/view?id=<?= $log['id'] ?>" class="btn btn-sm btn-outline-secondary">
                                    <i class="fas fa-eye me-1"></i>View
                                </a>
                            </li>
                        <?php endforeach; ?>

                        <?php if (empty($recentReceiving)): ?>
                            <li class="list-group-item small text-muted text-center py-3">
                                <i class="fas fa-info-circle me-1"></i>No recent logs.
                                <?php if (RoleHelper::hasPermission('create_receiving_logs')): ?>
                                    <br><a href="<?= BASE_URL ?>receiving/add" class="text-decoration-none">Create your first log</a>
                                <?php endif; ?>
                            </li>
                        <?php endif; ?>
                    </ul>
                </div>
            </div>
        </div>

        <div class="col-md-6">
            <div class="card shadow-sm border-0 h-100">
                <div class="card-body">
                    <h5 class="card-title">
                        <i class="fas fa-boxes me-2"></i>Recent Inventory Items
                    </h5>
                    <ul class="list-group list-group-flush">
                        <?php foreach ($recentItems as $item): ?>
                            <li class="list-group-item small d-flex justify-content-between align-items-center">
                                <div>
                                    <strong><?= htmlspecialchars($item['product_name']) ?></strong>
                                    <br><small class="text-muted">SKU: <?= htmlspecialchars($item['sku']) ?></small>
                                    <br><small class="text-muted"><?= date('M d, Y', strtotime($item['created_at'])) ?></small>
                                </div>
                                <a href="<?= BASE_URL ?>inventory/view?id=<?= $item['id'] ?>" class="btn btn-sm btn-outline-secondary">
                                    <i class="fas fa-eye me-1"></i>View
                                </a>
                            </li>
                        <?php endforeach; ?>
                        
                        <?php if (empty($recentItems)): ?>
                            <li class="list-group-item small text-muted text-center py-3">
                                <i class="fas fa-info-circle me-1"></i>No recent items.
                                <?php if (RoleHelper::hasPermission('add_inventory')): ?>
                                    <br><a href="<?= BASE_URL ?>inventory/add" class="text-decoration-none">Add your first item</a>
                                <?php endif; ?>
                            </li>
                        <?php endif; ?>
                    </ul>
                </div>
            </div>
        </div>
    </div>
</div>

<!-- Mobile Storefront Modal -->
<div class="modal fade" id="storefrontModal" tabindex="-1" aria-labelledby="storefrontModalLabel" aria-hidden="true">
    <div class="modal-dialog modal-fullscreen">
        <div class="modal-content">
            <div class="modal-header bg-dark text-white">
                <h5 class="modal-title" id="storefrontModalLabel">
                    <i class="fas fa-store me-2"></i>Your Storefront Preview
                </h5>
                <button type="button" class="btn-close btn-close-white" data-bs-dismiss="modal" aria-label="Close"></button>
            </div>
            <div class="modal-body p-0">
                <iframe id="storefrontFrame" src="" style="width: 100%; height: calc(100vh - 120px); border: none;"></iframe>
            </div>
            <div class="modal-footer bg-light">
                <button type="button" class="btn btn-outline-secondary btn-sm" data-bs-dismiss="modal">
                    <i class="fas fa-arrow-left me-1"></i>Back to Dashboard
                </button>
                <button type="button" class="btn btn-primary btn-sm" id="openInNewTab">
                    <i class="fas fa-external-link-alt me-1"></i>Open in New Tab
                </button>
            </div>
        </div>
    </div>
</div>

<!-- Custom CSS for Dashboard -->
<style>
.modal-fullscreen .modal-content {
    height: 100vh;
}

#storefrontFrame {
    transition: opacity 0.3s ease;
}

.modal-header {
    border-bottom: 1px solid rgba(255, 255, 255, 0.2);
}

.modal-footer {
    border-top: 1px solid #dee2e6;
}

/* Dashboard card improvements */
.card {
    transition: transform 0.2s ease, box-shadow 0.2s ease;
}

.card:hover {
    transform: translateY(-2px);
    box-shadow: 0 4px 12px rgba(0, 0, 0, 0.15);
}

/* Badge styling */
.badge.fs-6 {
    font-size: 0.875rem !important;
}

/* List improvements */
.list-group-item {
    border-left: none;
    border-right: none;
    transition: background-color 0.2s ease;
}

.list-group-item:hover {
    background-color: rgba(0, 0, 0, 0.025);
}

.list-group-item:first-child {
    border-top: none;
}

.list-group-item:last-child {
    border-bottom: none;
}

/* Permission-protected elements styling */
[data-permission].permission-denied {
    opacity: 0.6;
    pointer-events: none;
    position: relative;
}

[data-permission].permission-denied::after {
    content: "\f023";
    font-family: "Font Awesome 5 Free";
    font-weight: 900;
    position: absolute;
    top: 50%;
    right: 8px;
    transform: translateY(-50%);
    color: #dc3545;
    font-size: 12px;
}

/* Mobile-specific adjustments */
@media (max-width: 768px) {
    .modal-header {
        padding: 0.75rem 1rem;
    }
    
    .modal-footer {
        padding: 0.75rem 1rem;
        gap: 0.5rem;
    }
    
    .modal-footer .btn {
        flex: 1;
    }
    
    .d-grid.gap-2.d-sm-flex {
        gap: 0.5rem !important;
    }
    
    .btn-md {
        padding: 0.5rem 1rem;
        font-size: 0.9rem;
    }
}

/* Desktop enhancements */
@media (min-width: 768px) {
    .border-start {
        border-left: 2px solid #dee2e6 !important;
    }
}
</style>

<!-- Chart.js -->
<script src="https://cdn.jsdelivr.net/npm/chart.js"></script>
<script>
const ctx = document.getElementById('weeklyTrendChart').getContext('2d');
const weeklyTrendChart = new Chart(ctx, {
    type: 'line',
    data: {
        labels: <?= json_encode($trendLabels) ?>,
        datasets: [{
            label: 'Logs',
            data: <?= json_encode($trendCounts) ?>,
            borderColor: '#0d6efd',
            backgroundColor: 'rgba(13, 110, 253, 0.1)',
            tension: 0.3,
            fill: true
        }]
    },
    options: {
        responsive: true,
        scales: {
            y: { beginAtZero: true, ticks: { precision: 0 } }
        }
    }
});
</script>

<!-- Responsive Storefront Viewing Script -->
<script>
document.addEventListener('DOMContentLoaded', function() {
    const viewStoreBtn = document.getElementById('viewStoreBtn');
    const storefrontModal = new bootstrap.Modal(document.getElementById('storefrontModal'));
    const storefrontFrame = document.getElementById('storefrontFrame');
    const openInNewTabBtn = document.getElementById('openInNewTab');
    
    let storeUrl = viewStoreBtn.getAttribute('data-store-url');
    
    // Device detection
    function isMobile() {
        return window.innerWidth <= 768 || /Android|webOS|iPhone|iPad|iPod|BlackBerry|IEMobile|Opera Mini/i.test(navigator.userAgent);
    }
    
    // Handle View Store button click
    viewStoreBtn.addEventListener('click', function(e) {
        e.preventDefault();
        
        if (isMobile()) {
            // Mobile: Show in modal
            showStorefrontModal();
        } else {
            // Desktop: Open in new tab
            window.open(storeUrl, '_blank');
        }
    });
    
    // Show storefront in modal
    function showStorefrontModal() {
        // Show modal and load storefront immediately
        storefrontModal.show();
        storefrontFrame.src = storeUrl;
    }
    
    // Handle iframe load
    storefrontFrame.addEventListener('load', function() {
        // Iframe loaded successfully
    });
    
    // Handle "Open in New Tab" button
    openInNewTabBtn.addEventListener('click', function() {
        window.open(storeUrl, '_blank');
    });
    
    // Handle modal close - clean up iframe
    document.getElementById('storefrontModal').addEventListener('hidden.bs.modal', function() {
        storefrontFrame.src = '';
    });
    
    // Handle window resize - switch to new tab if user rotates to desktop size
    window.addEventListener('resize', function() {
        if (!isMobile() && document.getElementById('storefrontModal').classList.contains('show')) {
            storefrontModal.hide();
            window.open(storeUrl, '_blank');
        }
    });
});
</script>

<?php include __DIR__ . '/partials/footer.php'; ?>