<?php
require_once __DIR__ . '/../../config/config.php';
require_once __DIR__ . '/../../config/db.php';
require_once __DIR__ . '/../../helpers/AuthHelper.php';
require_once __DIR__ . '/../../helpers/RoleHelper.php';

// UPDATED: Require specific permission for viewing all inventory
AuthHelper::requirePermission('view_all_inventory');

$organization_id = $_SESSION['organization_id'];
$inventoryItems = [];
$error = '';

try {
    $stmt = $pdo->prepare("CALL whsale_inventory_pro_get_inventory_items_by_org_id(?)");
    $stmt->execute([$organization_id]);
    $inventoryItems = $stmt->fetchAll();

    $search = trim($_GET['search'] ?? '');
    $receivedDate = $_GET['received_date'] ?? '';

    $inventoryItems = array_filter($inventoryItems, function ($item) use ($search, $receivedDate) {
        $match = true;

        if ($search) {
            $match &= stripos($item['product_name'], $search) !== false || 
                     stripos($item['sku'], $search) !== false ||
                     stripos($item['location'], $search) !== false;
        }

        if ($receivedDate) {
            $match &= date('Y-m-d', strtotime($item['created_at'])) === $receivedDate;
        }

        return $match;
    });

    $stmt->closeCursor();
} catch (Exception $e) {
    $error = "Unable to load inventory items: " . $e->getMessage();
}
?>

<?php include __DIR__ . '/../partials/head.php'; ?>

<div class="container mt-4 mb-5">
    <div class="d-flex flex-wrap gap-2 justify-content-between align-items-center mb-3">
        <div>
            <h4 class="mb-0">Manage Inventory</h4>
            <small class="text-muted">Organization-wide inventory management</small>
        </div>
        
        <div class="d-flex gap-2 flex-wrap">
            <!-- UPDATED: Add inventory button with permission check -->
            <?php if (RoleHelper::hasPermission('add_inventory')): ?>
                <a href="<?= BASE_URL ?>receiving" class="btn btn-outline-primary btn-sm" data-permission="add_inventory">
                    <i class="fas fa-truck me-1"></i>Add via Receiving
                </a>
            <?php endif; ?>
            
            <?php if (RoleHelper::hasPermission('export_inventory_data')): ?>
                <button class="btn btn-outline-success btn-sm" onclick="exportInventory()" data-permission="export_inventory_data">
                    <i class="fas fa-download me-1"></i>Export
                </button>
            <?php endif; ?>
        </div>
    </div>

    <!-- Enhanced Filter Form -->
    <form method="GET" class="card p-3 mb-3 shadow-sm">
        <div class="row g-3">
            <div class="col-md-6">
                <label for="search" class="form-label">Text Search</label>
                <input type="text" name="search" value="<?= htmlspecialchars($_GET['search'] ?? '') ?>" 
                       class="form-control" placeholder="Search by Item, SKU, or Location">
            </div>
            <div class="col-md-4">
                <label for="received_date" class="form-label">Date Added</label>
                <input type="date" id="received_date" name="received_date" 
                       value="<?= htmlspecialchars($_GET['received_date'] ?? '') ?>" class="form-control">
            </div>
            <div class="col-md-2 d-flex align-items-end">
                <div class="d-flex gap-2 w-100">
                    <button class="btn btn-outline-secondary flex-fill" type="submit">
                        <i class="fas fa-filter me-1"></i>Filter
                    </button>
                    <a href="<?= BASE_URL ?>inventory/manage" class="btn btn-outline-danger flex-fill">
                        <i class="fas fa-times me-1"></i>Clear
                    </a>
                </div>
            </div>
        </div>
    </form>

    <?php if (!empty($error)): ?>
        <div class="alert alert-danger">
            <i class="fas fa-exclamation-circle me-2"></i>
            <?= htmlspecialchars($error) ?>
        </div>
    <?php endif; ?>

    <!-- Results Summary -->
    <?php if (!empty($inventoryItems)): ?>
        <div class="mb-3">
            <small class="text-muted">
                <i class="fas fa-list me-1"></i>
                Showing <?= count($inventoryItems) ?> inventory item<?= count($inventoryItems) !== 1 ? 's' : '' ?>
                <?php if (!empty($_GET['search']) || !empty($_GET['received_date'])): ?>
                    (filtered)
                <?php endif; ?>
            </small>
        </div>
    <?php endif; ?>

    <!-- Desktop View -->
    <div class="table-responsive d-none d-lg-block">
        <table class="table table-bordered table-hover table-sm bg-white">
            <thead class="table-light">
                <tr>
                    <th>Item</th>
                    <th>SKU</th>
                    <th>Qty</th>
                    <th>Location</th>
                    <th>Expires</th>
                    <th>Added</th>
                    <th>Actions</th>
                </tr>
            </thead>
            <tbody>
                <?php if (empty($inventoryItems)): ?>
                    <tr>
                        <td colspan="7" class="text-center py-4">
                            <div class="text-muted">
                                <i class="fas fa-box-open fa-2x mb-2"></i>
                                <p class="mb-0">No inventory items found.</p>
                                <?php if (empty($_GET['search']) && empty($_GET['received_date'])): ?>
                                    <?php if (RoleHelper::hasPermission('add_inventory')): ?>
                                        <small>
                                            <a href="<?= BASE_URL ?>receiving" class="text-decoration-none">
                                                Start by creating a receiving log
                                            </a>
                                        </small>
                                    <?php else: ?>
                                        <small class="text-muted">Contact your administrator to add inventory items.</small>
                                    <?php endif; ?>
                                <?php else: ?>
                                    <small>Try adjusting your filters.</small>
                                <?php endif; ?>
                            </div>
                        </td>
                    </tr>
                <?php else: ?>
                    <?php foreach ($inventoryItems as $item): ?>
                        <tr>
                            <td>
                                <div class="fw-semibold"><?= htmlspecialchars($item['product_name']) ?></div>
                                <?php if ($item['receiving_id']): ?>
                                    <small class="text-muted">From Log #<?= htmlspecialchars($item['receiving_id']) ?></small>
                                <?php endif; ?>
                            </td>
                            <td><?= htmlspecialchars($item['sku']) ?: '-' ?></td>
                            <td><?= htmlspecialchars($item['quantity']) ?> <?= htmlspecialchars($item['unit_type']) ?></td>
                            <td><?= htmlspecialchars($item['location'] ?? '-') ?></td>
                            <td>
                                <?php if ($item['expiration_date']): ?>
                                    <?= date('M d, Y', strtotime($item['expiration_date'])) ?>
                                    <?php 
                                    $daysUntilExpiry = floor((strtotime($item['expiration_date']) - time()) / 86400);
                                    if ($daysUntilExpiry < 0): ?>
                                        <br><span class="badge bg-danger">Expired</span>
                                    <?php elseif ($daysUntilExpiry <= 7): ?>
                                        <br><span class="badge bg-warning text-dark">Expires soon</span>
                                    <?php endif; ?>
                                <?php else: ?>
                                    <span class="text-muted">-</span>
                                <?php endif; ?>
                            </td>
                            <td><?= date('M d, Y', strtotime($item['created_at'])) ?></td>
                            <td>
                                <!-- UPDATED: Action buttons with permission checks -->
                                <div class="d-flex gap-1 flex-wrap">
                                    <a href="<?= BASE_URL ?>inventory/view?id=<?= $item['id'] ?>&from=inventory" 
                                       class="btn btn-sm btn-outline-primary">
                                        <i class="fas fa-eye me-1"></i>View
                                    </a>
                                    
                                    <?php if (RoleHelper::hasPermission('edit_inventory')): ?>
                                        <a href="<?= BASE_URL ?>inventory/edit?id=<?= $item['id'] ?>&from=inventory" 
                                           class="btn btn-sm btn-outline-secondary" data-permission="edit_inventory">
                                            <i class="fas fa-edit me-1"></i>Edit
                                        </a>
                                    <?php endif; ?>
                                    
                                    <?php if (RoleHelper::hasPermission('delete_inventory')): ?>
                                        <button class="btn btn-sm btn-outline-danger" 
                                                onclick="confirmDeleteItem(<?= $item['id'] ?>)" 
                                                data-permission="delete_inventory">
                                            <i class="fas fa-trash me-1"></i>Delete
                                        </button>
                                    <?php endif; ?>
                                </div>
                            </td>
                        </tr>
                    <?php endforeach; ?>
                <?php endif; ?>
            </tbody>
        </table>
    </div>

    <!-- Mobile Card View -->
    <div class="d-block d-lg-none">
        <?php if (empty($inventoryItems)): ?>
            <div class="alert alert-info text-center">
                <i class="fas fa-box-open fa-2x mb-3"></i>
                <h6>No inventory items found</h6>
                <?php if (empty($_GET['search']) && empty($_GET['received_date'])): ?>
                    <?php if (RoleHelper::hasPermission('add_inventory')): ?>
                        <p class="mb-2">Start by creating a receiving log to add inventory items.</p>
                        <a href="<?= BASE_URL ?>receiving" class="btn btn-primary btn-sm">
                            <i class="fas fa-truck me-1"></i>Create Receiving Log
                        </a>
                    <?php else: ?>
                        <p class="mb-0 text-muted">Contact your administrator to add inventory items.</p>
                    <?php endif; ?>
                <?php else: ?>
                    <p class="mb-0">Try adjusting your filters above.</p>
                <?php endif; ?>
            </div>
        <?php else: ?>
            <?php foreach ($inventoryItems as $item): ?>
                <div class="card mb-3 shadow-sm">
                    <div class="card-body">
                        <div class="d-flex justify-content-between align-items-start mb-2">
                            <h5 class="card-title mb-0"><?= htmlspecialchars($item['product_name']) ?></h5>
                            <?php if ($item['expiration_date']): ?>
                                <?php 
                                $daysUntilExpiry = floor((strtotime($item['expiration_date']) - time()) / 86400);
                                if ($daysUntilExpiry < 0): ?>
                                    <span class="badge bg-danger">Expired</span>
                                <?php elseif ($daysUntilExpiry <= 7): ?>
                                    <span class="badge bg-warning text-dark">Expires soon</span>
                                <?php endif; ?>
                            <?php endif; ?>
                        </div>
                        
                        <p class="mb-1"><strong>SKU:</strong> <?= htmlspecialchars($item['sku']) ?: 'Not specified' ?></p>
                        <p class="mb-1"><strong>Qty:</strong> <?= htmlspecialchars($item['quantity']) ?> <?= htmlspecialchars($item['unit_type']) ?></p>
                        <p class="mb-1"><strong>Location:</strong> <?= htmlspecialchars($item['location'] ?? 'Not specified') ?></p>
                        
                        <?php if ($item['expiration_date']): ?>
                            <p class="mb-1"><strong>Expires:</strong> <?= date('M d, Y', strtotime($item['expiration_date'])) ?></p>
                        <?php endif; ?>
                        
                        <p class="mb-1"><strong>Added:</strong> <?= date('M d, Y', strtotime($item['created_at'])) ?></p>
                        
                        <?php if ($item['receiving_id']): ?>
                            <p class="mb-3"><strong>From:</strong> Receiving Log #<?= htmlspecialchars($item['receiving_id']) ?></p>
                        <?php else: ?>
                            <div class="mb-3"></div>
                        <?php endif; ?>
                        
                        <!-- UPDATED: Mobile action buttons with permission checks -->
                        <div class="d-flex gap-2 flex-wrap">
                            <a href="<?= BASE_URL ?>inventory/view?id=<?= $item['id'] ?>&from=inventory" 
                               class="btn btn-sm btn-outline-primary flex-fill">
                                <i class="fas fa-eye me-1"></i>View
                            </a>
                            
                            <?php if (RoleHelper::hasPermission('edit_inventory')): ?>
                                <a href="<?= BASE_URL ?>inventory/edit?id=<?= $item['id'] ?>&from=inventory" 
                                   class="btn btn-sm btn-outline-secondary flex-fill" data-permission="edit_inventory">
                                    <i class="fas fa-edit me-1"></i>Edit
                                </a>
                            <?php endif; ?>
                            
                            <?php if (RoleHelper::hasPermission('delete_inventory')): ?>
                                <button class="btn btn-sm btn-outline-danger flex-fill" 
                                        onclick="confirmDeleteItem(<?= $item['id'] ?>)" 
                                        data-permission="delete_inventory">
                                    <i class="fas fa-trash me-1"></i>Delete
                                </button>
                            <?php endif; ?>
                        </div>
                    </div>
                </div>
            <?php endforeach; ?>
        <?php endif; ?>
    </div>
</div>

<!-- UPDATED: Delete confirmation and export scripts -->
<script>
function confirmDeleteItem(itemId) {
    const confirmed = confirm(
        "Are you sure you want to delete this inventory item?\n\n" +
        "This action cannot be undone.\n\n" +
        "Click OK to proceed with deletion."
    );
    
    if (confirmed) {
        // Check permission before allowing delete
        requirePermission('delete_inventory', function() {
            // Create hidden form and submit
            const form = document.createElement('form');
            form.method = 'POST';
            form.action = '<?= BASE_URL ?>inventory/delete';
            form.style.display = 'none';
            
            const itemIdInput = document.createElement('input');
            itemIdInput.type = 'hidden';
            itemIdInput.name = 'item_id';
            itemIdInput.value = itemId;
            
            const confirmInput = document.createElement('input');
            confirmInput.type = 'hidden';
            confirmInput.name = 'confirm_delete';
            confirmInput.value = '1';
            
            form.appendChild(itemIdInput);
            form.appendChild(confirmInput);
            document.body.appendChild(form);
            form.submit();
        });
    }
}

function exportInventory() {
    // Check permission before allowing export
    requirePermission('export_inventory_data', function() {
        // Create export URL with current filters
        const urlParams = new URLSearchParams(window.location.search);
        const exportUrl = '<?= BASE_URL ?>inventory/export?' + urlParams.toString();
        window.location.href = exportUrl;
    });
}
</script>

<!-- UPDATED: Custom CSS for permission elements and responsive design -->
<style>
/* Permission-protected elements styling */
[data-permission].permission-denied {
    opacity: 0.6;
    pointer-events: none;
    position: relative;
}

[data-permission].permission-denied::after {
    content: "\f023";
    font-family: "Font Awesome 5 Free";
    font-weight: 900;
    position: absolute;
    top: 50%;
    right: 8px;
    transform: translateY(-50%);
    color: #dc3545;
    font-size: 12px;
}

/* Expiration badges */
.badge.bg-danger {
    animation: pulse 2s infinite;
}

@keyframes pulse {
    0% { opacity: 1; }
    50% { opacity: 0.5; }
    100% { opacity: 1; }
}

/* Desktop action buttons */
@media (min-width: 992px) {
    .table td .d-flex {
        justify-content: flex-start;
    }
}

/* Mobile responsiveness */
@media (max-width: 768px) {
    .d-flex.gap-2.flex-wrap {
        gap: 0.5rem !important;
    }
    
    .btn-sm {
        font-size: 0.775rem;
        padding: 0.25rem 0.5rem;
    }
    
    .flex-fill {
        flex: 1;
    }
}

/* Filter form enhancements */
.card {
    transition: box-shadow 0.3s ease;
}

.card:hover {
    box-shadow: 0 0.125rem 0.5rem rgba(0, 0, 0, 0.15) !important;
}

/* Table enhancements */
.table-hover tbody tr:hover {
    background-color: rgba(0, 123, 255, 0.05);
}

.fw-semibold {
    font-weight: 600;
}
</style>

<?php include __DIR__ . '/../partials/footer.php'; ?>