<?php
require_once __DIR__ . '/../../config/config.php';
require_once __DIR__ . '/../../helpers/AuthHelper.php';
require_once __DIR__ . '/../../helpers/RoleHelper.php';

AuthHelper::requirePermission('edit_receiving_logs');

$receiving_id = $_GET['id'] ?? null;
if (!$receiving_id || !is_numeric($receiving_id)) {
    header("Location: " . BASE_URL . "receiving");
    exit;
}

$error = '';
$success = '';
$log = null;
$receivingPhotos = [];
$organization_id = $_SESSION['organization_id'];
$user_id = $_SESSION['user_id']; // Changed back to user_id for consistency

// Fetch existing categories for this organization
$categories = [];
try {
    $stmt = $pdo->prepare("SELECT id, category_name FROM whsale_inventory_pro_categories WHERE organization_id = ? ORDER BY category_name ASC");
    $stmt->execute([$organization_id]);
    $categories = $stmt->fetchAll(PDO::FETCH_ASSOC);
} catch (Exception $e) {
    error_log("Error fetching categories: " . $e->getMessage());
}

try {
    // Query to get receiving log - all users can view/edit (except delete)
    $stmt = $pdo->prepare("
        SELECT r.*, c.category_name 
        FROM whsale_inventory_pro_receiving_log r
        LEFT JOIN whsale_inventory_pro_categories c ON r.category_id = c.id
        WHERE r.id = ? AND r.organization_id = ?
    ");
    $stmt->execute([$receiving_id, $organization_id]);
    $log = $stmt->fetch();
    $stmt->closeCursor();

    if (!$log) {
        throw new Exception("Receiving log not found or you don't have permission to access it.");
    }

    $stmt = $pdo->prepare("SELECT * FROM whsale_inventory_pro_receiving_photos WHERE receiving_id = ? ORDER BY uploaded_at DESC");
    $stmt->execute([$receiving_id]);
    $receivingPhotos = $stmt->fetchAll();
    $stmt->closeCursor();
} catch (Exception $e) {
    $error = $e->getMessage();
}

// Handle update
if ($_SERVER['REQUEST_METHOD'] === 'POST') {
    // Handle soft delete - only admins can delete
    if (isset($_POST['delete_log'])) {
        if (!RoleHelper::canDelete()) {
            $error = "Only administrators can delete receiving logs.";
        } else {
            try {
                $stmt = $pdo->prepare("UPDATE whsale_inventory_pro_receiving_log SET is_active = 0 WHERE id = ? AND organization_id = ?");
                $stmt->execute([$receiving_id, $organization_id]);
                
                $_SESSION['success'] = "Receiving log has been deleted successfully.";
                header("Location: " . BASE_URL . "receiving");
                exit;
            } catch (Exception $e) {
                $error = "Delete failed: " . $e->getMessage();
            }
        }
    }
    
    // Handle regular update - all users can edit
    else {
        $vendor_name = trim($_POST['vendor_name'] ?? '');
        $po_number = trim($_POST['po_number'] ?? '');
        $delivery_date = $_POST['delivery_date'] ?? null;
        $notes = trim($_POST['notes'] ?? '');
        $category_id = $_POST['category_id'] ?? null;
        $new_category = trim($_POST['new_category'] ?? '');

        if ($vendor_name && $delivery_date) {
            try {
                $pdo->beginTransaction();

                // Handle category logic (same as in add.php)
                $final_category_id = null;
                
                if (!empty($new_category)) {
                    // User wants to create a new category
                    $stmt = $pdo->prepare("INSERT IGNORE INTO whsale_inventory_pro_categories (organization_id, category_name) VALUES (?, ?)");
                    $stmt->execute([$organization_id, $new_category]);
                    
                    // Get the category ID (whether newly created or existing)
                    $stmt = $pdo->prepare("SELECT id FROM whsale_inventory_pro_categories WHERE organization_id = ? AND category_name = ?");
                    $stmt->execute([$organization_id, $new_category]);
                    $final_category_id = $stmt->fetchColumn();
                } elseif (!empty($category_id) && $category_id !== '') {
                    // User selected an existing category
                    $final_category_id = $category_id;
                }
                // If both are empty, $final_category_id remains null (no category)

                // Update receiving log - all users can update records in their organization
                $stmt = $pdo->prepare("
                    UPDATE whsale_inventory_pro_receiving_log 
                    SET vendor_name = ?, po_number = ?, delivery_date = ?, notes = ?, category_id = ?
                    WHERE id = ? AND organization_id = ?
                ");
                $stmt->execute([$vendor_name, $po_number, $delivery_date, $notes, $final_category_id, $receiving_id, $organization_id]);
                
                $receivingLogUpdated = $stmt->rowCount() > 0;
                error_log("DEBUG: Receiving log update - rows affected: " . $stmt->rowCount());

                // UPDATED: Handle photo caption updates
                $captionsUpdated = 0;
                if (isset($_POST['photo_captions']) && is_array($_POST['photo_captions'])) {
                    foreach ($_POST['photo_captions'] as $photo_id => $caption) {
                        if (is_numeric($photo_id)) {
                            // Verify photo belongs to this receiving log and organization
                            $stmt = $pdo->prepare("
                                SELECT rp.id, rp.caption 
                                FROM whsale_inventory_pro_receiving_photos rp
                                JOIN whsale_inventory_pro_receiving_log rl ON rp.receiving_id = rl.id
                                WHERE rp.id = ? AND rl.id = ? AND rl.organization_id = ?
                            ");
                            $stmt->execute([$photo_id, $receiving_id, $organization_id]);
                            $photoData = $stmt->fetch();
                            
                            if ($photoData) {
                                // Check permission to manage captions
                                $canManageCaptions = RoleHelper::isOwner() || RoleHelper::hasPermission('manage_receiving_photos');
                                
                                if ($canManageCaptions) {
                                    $newCaption = trim($caption);
                                    $oldCaption = trim($photoData['caption'] ?? '');
                                    
                                    // Only update if caption actually changed
                                    if ($newCaption !== $oldCaption) {
                                        $stmt = $pdo->prepare("UPDATE whsale_inventory_pro_receiving_photos SET caption = ? WHERE id = ?");
                                        $stmt->execute([$newCaption, $photo_id]);
                                        if ($stmt->rowCount() > 0) {
                                            $captionsUpdated++;
                                            error_log("DEBUG: Updated caption for photo $photo_id: '$oldCaption' -> '$newCaption'");
                                        }
                                    }
                                }
                            }
                        }
                    }
                }
                
                error_log("DEBUG: Captions updated: $captionsUpdated");
                
                // Check if any changes were made
                if (!$receivingLogUpdated && $captionsUpdated === 0) {
                    throw new Exception("No changes were made or you don't have permission to edit this record.");
                }
                
                $pdo->commit();
                $success = "Receiving log updated successfully.";

                // Reload updated data with category
                $stmt = $pdo->prepare("
                    SELECT r.*, c.category_name 
                    FROM whsale_inventory_pro_receiving_log r
                    LEFT JOIN whsale_inventory_pro_categories c ON r.category_id = c.id
                    WHERE r.id = ? AND r.organization_id = ?
                ");
                $stmt->execute([$receiving_id, $organization_id]);
                $log = $stmt->fetch();
                $stmt->closeCursor();

                // Refresh categories list in case a new one was added
                $stmt = $pdo->prepare("SELECT id, category_name FROM whsale_inventory_pro_categories WHERE organization_id = ? ORDER BY category_name ASC");
                $stmt->execute([$organization_id]);
                $categories = $stmt->fetchAll(PDO::FETCH_ASSOC);

                // Reload photos with updated captions
                $stmt = $pdo->prepare("SELECT * FROM whsale_inventory_pro_receiving_photos WHERE receiving_id = ? ORDER BY uploaded_at DESC");
                $stmt->execute([$receiving_id]);
                $receivingPhotos = $stmt->fetchAll();
                $stmt->closeCursor();

            } catch (Exception $e) {
                $pdo->rollback();
                $error = "Update failed: " . $e->getMessage();
            }
        } else {
            $error = "Vendor name and delivery date are required.";
        }
    }
}
?>

<?php include __DIR__ . '/../partials/head.php'; ?>
<?php include __DIR__ . '/../partials/spinner_overlay.php'; ?>

<div class="container mt-4 mb-5">
    <div class="d-flex align-items-center mb-3">
        <h4 class="mb-0 me-3">Edit Receiving Log #<?= htmlspecialchars($receiving_id) ?></h4>
        <?php if (!empty($log['category_name'])): ?>
            <span class="badge bg-secondary">
                <i class="fas fa-tag me-1"></i><?= htmlspecialchars($log['category_name']) ?>
            </span>
        <?php endif; ?>
        <div class="ms-auto">
            <?= RoleHelper::getRoleBadge() ?>
        </div>
    </div>

    <!-- Options Dropdown - underneath the title -->
    <div class="d-flex justify-content-between align-items-center mb-4">
        <div></div> <!-- Empty div for spacing -->
        <div class="dropdown">
            <button class="btn btn-outline-secondary btn-sm dropdown-toggle" type="button" 
                    id="optionsDropdown" data-bs-toggle="dropdown" aria-expanded="false">
                <i class="fas fa-cog me-1"></i>Options
            </button>
            <ul class="dropdown-menu dropdown-menu-end" aria-labelledby="optionsDropdown">
                <?php if (RoleHelper::canDelete()): ?>
                    <li>
                        <a class="dropdown-item text-danger" href="#" 
                           onclick="confirmDeleteLog(<?= $receiving_id ?>); return false;">
                            <i class="fas fa-trash me-2"></i>Delete Log
                        </a>
                    </li>
                    <li><hr class="dropdown-divider"></li>
                <?php endif; ?>
                <li>
                    <a class="dropdown-item" href="<?= BASE_URL ?>receiving/view?id=<?= urlencode($receiving_id) ?>">
                        <i class="fas fa-eye me-2"></i>View Details
                    </a>
                </li>
            </ul>
        </div>
    </div>

    <?php if ($error): ?>
        <div class="alert alert-danger"><?= htmlspecialchars($error) ?></div>
    <?php endif; ?>

    <?php if ($success): ?>
        <div class="alert alert-success"><?= htmlspecialchars($success) ?></div>
    <?php endif; ?>

    <?php if ($log): ?>
        <!-- UPDATED: Single form for all changes -->
        <form method="POST" onsubmit="showSpinner()">
            <!-- Main form fields -->
            <div class="card p-4 shadow-sm border-0 bg-white mb-4">
                <h6 class="mb-3">
                    <i class="fas fa-edit me-2"></i>Receiving Log Details
                </h6>
                
                <div class="row">
                    <div class="col-md-6 mb-3">
                        <label class="form-label">Vendor Name <span class="text-danger">*</span></label>
                        <input type="text" name="vendor_name" class="form-control" 
                               value="<?= htmlspecialchars($log['vendor_name']) ?>" required>
                    </div>
                    <div class="col-md-6 mb-3">
                        <label class="form-label">PO Number</label>
                        <input type="text" name="po_number" class="form-control" 
                               value="<?= htmlspecialchars($log['po_number']) ?>">
                    </div>
                    
                    <div class="col-md-6 mb-3">
                        <label class="form-label">Delivery Date <span class="text-danger">*</span></label>
                        <input type="date" name="delivery_date" class="form-control" 
                               value="<?= htmlspecialchars($log['delivery_date']) ?>" required>
                    </div>
                    
                    <div class="col-md-6 mb-3">
                        <label class="form-label">Category</label>
                        <div class="category-selector">
                            <!-- Existing Category Dropdown -->
                            <select name="category_id" id="categorySelect" class="form-select mb-2">
                                <option value="">Select existing category (optional)</option>
                                <?php foreach ($categories as $category): ?>
                                    <option value="<?= $category['id'] ?>" 
                                            <?= ($log['category_id'] == $category['id']) ? 'selected' : '' ?>>
                                        <?= htmlspecialchars($category['category_name']) ?>
                                    </option>
                                <?php endforeach; ?>
                            </select>
                            
                            <!-- OR divider -->
                            <div class="text-center text-muted small mb-2">
                                <span class="px-2 bg-white">OR</span>
                                <hr class="mt-0" style="margin-top: -12px; z-index: -1;">
                            </div>
                            
                            <!-- New Category Input -->
                            <div class="input-group">
                                <input type="text" name="new_category" id="newCategoryInput" class="form-control" 
                                       placeholder="Create new category..." maxlength="100">
                                <button type="button" class="btn btn-outline-secondary" id="clearCategoryBtn" 
                                        onclick="clearCategorySelection()" title="Clear selection">
                                    <i class="fas fa-times"></i>
                                </button>
                            </div>
                            
                            <div class="form-text">
                                <i class="fas fa-info-circle me-1"></i>
                                Select from existing categories or type a new one. Leave blank to remove category.
                            </div>
                        </div>
                    </div>
                    
                    <div class="col-md-12 mb-3">
                        <label class="form-label">Notes</label>
                        <textarea name="notes" class="form-control" rows="3"><?= htmlspecialchars($log['notes']) ?></textarea>
                    </div>
                </div>
            </div>

            <!-- UPDATED: Photo section integrated into the form -->
            <?php if (!empty($receivingPhotos)): ?>
                <div class="card border-0 shadow-sm mb-4">
                    <div class="card-header bg-white">
                        <h6 class="mb-0">
                            <i class="fas fa-images me-2"></i>Edit Pallet Photos
                            <span class="badge bg-secondary ms-2"><?= count($receivingPhotos) ?></span>
                        </h6>
                        <?php 
                        $canManageCaptions = RoleHelper::isOwner() || RoleHelper::hasPermission('manage_receiving_photos');
                        if (!$canManageCaptions): 
                        ?>
                            <small class="text-muted">You can view photos but cannot edit captions.</small>
                        <?php endif; ?>
                    </div>
                    <div class="card-body">
                        <div class="row g-3">
                            <?php foreach ($receivingPhotos as $photo): ?>
                                <div class="col-6 col-md-4 col-lg-3">
                                    <div class="border rounded shadow-sm p-2 bg-light text-center position-relative">
                                        <a href="<?= BASE_URL ?>public/uploads/receiving/<?= htmlspecialchars($photo['file_path']) ?>" target="_blank">
                                            <img src="<?= BASE_URL ?>public/uploads/receiving/<?= htmlspecialchars($photo['file_path']) ?>" 
                                                 class="img-fluid rounded mb-2" style="max-height: 180px; object-fit: cover;">
                                        </a>
                                        
                                        <!-- UPDATED: Caption input integrated into form -->
                                        <?php if ($canManageCaptions): ?>
                                            <input type="text" 
                                                   class="form-control form-control-sm mb-1" 
                                                   name="photo_captions[<?= $photo['id'] ?>]"
                                                   value="<?= htmlspecialchars($photo['caption'] ?? '') ?>" 
                                                   placeholder="Edit caption...">
                                        <?php else: ?>
                                            <?php if (!empty($photo['caption'])): ?>
                                                <p class="text-muted small mb-1"><?= htmlspecialchars($photo['caption']) ?></p>
                                            <?php else: ?>
                                                <p class="text-muted small mb-1 fst-italic">No caption</p>
                                            <?php endif; ?>
                                        <?php endif; ?>
                                        
                                        <!-- Regular users can't delete photos, only admins can delete photos -->
                                        <?php if (RoleHelper::canDelete()): ?>
                                            <button type="button" class="btn btn-sm btn-outline-danger btn-delete-photo w-100" 
                                                    data-photo-id="<?= $photo['id'] ?>">
                                                <i class="fas fa-trash me-1"></i>Delete Photo
                                            </button>
                                        <?php endif; ?>
                                    </div>
                                </div>
                            <?php endforeach; ?>
                        </div>
                    </div>
                </div>
            <?php endif; ?>

            <!-- UPDATED: Moved action buttons to bottom of form -->
            <div class="card p-4 shadow-sm border-0 bg-light">
                <div class="d-flex flex-wrap gap-2 justify-content-between align-items-center">
                    <div>
                        <h6 class="mb-1">
                            <i class="fas fa-save me-2"></i>Save All Changes
                        </h6>
                        <small class="text-muted">
                            This will save all form changes and photo captions together.
                        </small>
                    </div>
                    <div class="d-flex gap-2">
                        <button type="submit" class="btn btn-dark">
                            <i class="fas fa-save me-1"></i>Save Changes
                        </button>
                        <a href="<?= BASE_URL ?>receiving/view?id=<?= urlencode($receiving_id) ?>" class="btn btn-outline-secondary">
                            <i class="fas fa-times me-1"></i>Cancel
                        </a>
                    </div>
                </div>
            </div>
        </form>
    <?php endif; ?>
</div>

<!-- Custom CSS for Category Selector and Options Dropdown -->
<style>
.category-selector {
    position: relative;
}

.category-selector .form-select:focus,
.category-selector .form-control:focus {
    border-color: #0d6efd;
    box-shadow: 0 0 0 0.2rem rgba(13, 110, 253, 0.25);
}

.category-selector hr {
    position: relative;
    border-color: #dee2e6;
}

.category-selector .text-muted span {
    position: relative;
    z-index: 1;
}

#clearCategoryBtn {
    border-left: none;
}

.input-group .form-control:focus + .btn {
    border-color: #0d6efd;
    box-shadow: 0 0 0 0.2rem rgba(13, 110, 253, 0.25);
}

/* Options Dropdown Styling */
.dropdown-menu .dropdown-item.text-danger:hover {
    background-color: #dc3545;
    color: white;
}

.dropdown-menu .dropdown-item {
    transition: all 0.2s ease;
}

.dropdown-menu .dropdown-item:hover {
    background-color: #f8f9fa;
}

.dropdown-toggle::after {
    margin-left: 0.5em;
}

/* Form sections styling */
.card h6 {
    color: #495057;
}

.bg-light .card {
    background-color: #f8f9fa !important;
}

/* Responsive adjustments */
@media (max-width: 768px) {
    .d-flex.justify-content-between {
        flex-direction: column;
        gap: 1rem;
    }
    
    .dropdown {
        align-self: flex-end;
    }
    
    .d-flex.gap-2 {
        flex-direction: column;
    }
    
    .btn {
        text-align: center;
    }
}
</style>

<script>
function showSpinner() {
    const overlay = document.getElementById('globalSpinnerOverlay');
    if (overlay) {
        overlay.classList.remove('d-none');
        overlay.style.opacity = 0;
        overlay.style.transition = 'opacity 0.3s ease-in-out';
        setTimeout(() => overlay.style.opacity = 1, 10);
    }
}

// Handle category selection logic
document.addEventListener('DOMContentLoaded', function() {
    const categorySelect = document.getElementById('categorySelect');
    const newCategoryInput = document.getElementById('newCategoryInput');
    
    // When user selects an existing category, clear the new category input
    categorySelect.addEventListener('change', function() {
        if (this.value) {
            newCategoryInput.value = '';
        }
    });
    
    // When user types in new category, clear the existing category selection
    newCategoryInput.addEventListener('input', function() {
        if (this.value) {
            categorySelect.value = '';
        }
    });

    // UPDATED: Remove auto-save functionality for photo captions
    // Photo captions will now be saved with the main form

    // Delete photo functionality (only for admins)
    document.querySelectorAll('.btn-delete-photo').forEach(btn => {
        btn.addEventListener('click', function () {
            if (!confirm("Delete this photo? This action cannot be undone.")) return;
            const photoId = this.dataset.photoId;
            fetch("<?= BASE_URL ?>receiving/delete_photo", {
                method: "POST",
                headers: { 'Content-Type': 'application/x-www-form-urlencoded' },
                body: `photo_id=${photoId}`
            }).then(() => location.reload());
        });
    });
});

// Clear both category selections
function clearCategorySelection() {
    document.getElementById('categorySelect').value = '';
    document.getElementById('newCategoryInput').value = '';
}

// Handle soft delete confirmation
function confirmDeleteLog(receivingId) {
    // Custom confirmation modal
    const confirmed = confirm(
        "Are you sure you want to delete this receiving log?\n\n" +
        "This will:\n" +
        "• Hide the log from your receiving list\n" +
        "• Keep all data for recovery if needed\n" +
        "• Can be restored by contacting support\n\n" +
        "Click OK to proceed with deletion."
    );
    
    if (confirmed) {
        // Create and submit a hidden form for the delete action
        const form = document.createElement('form');
        form.method = 'POST';
        form.style.display = 'none';
        
        const deleteInput = document.createElement('input');
        deleteInput.type = 'hidden';
        deleteInput.name = 'delete_log';
        deleteInput.value = '1';
        
        form.appendChild(deleteInput);
        document.body.appendChild(form);
        form.submit();
    }
}
</script>

<?php if ($success): ?>
<script>
    document.addEventListener('DOMContentLoaded', () => {
        // Show success message briefly then redirect
        setTimeout(() => {
            window.location.href = "<?= BASE_URL ?>receiving/view?id=<?= urlencode($receiving_id) ?>";
        }, 1500);
    });
</script>
<?php endif; ?>

<?php include __DIR__ . '/../partials/footer.php'; ?>