<?php
require_once __DIR__ . '/../../config/config.php';
require_once __DIR__ . '/../../config/db.php';
require_once __DIR__ . '/../../helpers/AuthHelper.php';
require_once __DIR__ . '/../../helpers/RoleHelper.php';

// UPDATED: Basic login required for viewing (all users can view)
AuthHelper::requireLogin();

$receiving_id = $_GET['id'] ?? null;
if (!$receiving_id || !is_numeric($receiving_id)) {
    header("Location: " . BASE_URL . "receiving");
    exit;
}

$log = null;
$inventoryItems = [];
$receivingPhotos = [];
$error = '';
$isOnStorefront = false;

try {
    // Updated query to include category information
    $stmt = $pdo->prepare("
        SELECT r.*, c.category_name 
        FROM whsale_inventory_pro_receiving_log r
        LEFT JOIN whsale_inventory_pro_categories c ON r.category_id = c.id
        WHERE r.id = ?
    ");
    $stmt->execute([$receiving_id]);
    $log = $stmt->fetch();
    $stmt->closeCursor();

    if (!$log) {
        throw new Exception("Receiving log not found.");
    }

    // Check if this receiving log is already on the storefront
    $stmt = $pdo->prepare("SELECT id FROM whsale_inventory_pro_storefront_products WHERE receiving_id = ? LIMIT 1");
    $stmt->execute([$receiving_id]);
    $isOnStorefront = $stmt->fetch() !== false;
    $stmt->closeCursor();

    $stmt = $pdo->prepare("CALL whsale_inventory_pro_get_inventory_by_receiving(?)");
    $stmt->execute([$receiving_id]);
    $inventoryItems = $stmt->fetchAll();
    $stmt->closeCursor();

    $stmt = $pdo->prepare("SELECT * FROM whsale_inventory_pro_receiving_photos WHERE receiving_id = ? ORDER BY uploaded_at DESC");
    $stmt->execute([$receiving_id]);
    $receivingPhotos = $stmt->fetchAll();
    $stmt->closeCursor();
} catch (Exception $e) {
    $error = $e->getMessage();
}
?>

<?php include __DIR__ . '/../partials/head.php'; ?>

<div class="container mt-4 mb-5">
    <?php if ($error): ?>
        <div class="alert alert-danger"><?= htmlspecialchars($error) ?></div>
    <?php elseif ($log): ?>

        <div class="d-flex flex-wrap gap-2 justify-content-between align-items-center mb-3">
            <div>
                <h4 class="mb-0">Receiving Log: <?= htmlspecialchars($log['vendor_name']) ?></h4>
                <?php if (!empty($log['category_name'])): ?>
                    <span class="badge bg-secondary mt-1">
                        <i class="fas fa-tag me-1"></i><?= htmlspecialchars($log['category_name']) ?>
                    </span>
                <?php endif; ?>
            </div>
            <div class="d-flex gap-2 flex-wrap">
                <!-- UPDATED: Storefront upload with permission check -->
                <?php if ($isOnStorefront): ?>
                    <span class="badge bg-success fs-6 py-2 px-3">
                        <i class="fas fa-check-circle me-1"></i>This Item is Listed in Your Store
                    </span>
                <?php else: ?>
                    <?php if (RoleHelper::hasPermission('publish_to_storefront')): ?>
                        <a href="<?= BASE_URL ?>storefront/upload_form?receiving_id=<?= urlencode($log['id']) ?>" 
                           class="btn btn-sm btn-outline-success" data-permission="publish_to_storefront">
                            <i class="bi bi-box-arrow-up-right me-1"></i>Upload to Your Store
                        </a>
                    <?php endif; ?>
                <?php endif; ?>
                
                <!-- UPDATED: Edit button with permission check -->
                <?php if (RoleHelper::hasPermission('edit_receiving_logs')): ?>
                    <a href="<?= BASE_URL ?>receiving/edit?id=<?= urlencode($log['id']) ?>" 
                       class="btn btn-sm btn-outline-primary" data-permission="edit_receiving_logs">
                        <i class="fas fa-edit me-1"></i>Edit Log
                    </a>
                <?php endif; ?>
            </div>
        </div>
        
        <div class="card mb-4 shadow-sm border-0">
            <div class="card-body">
                <div class="row">
                    <div class="col-md-6">
                        <p><strong>Vendor:</strong> <?= htmlspecialchars($log['vendor_name']) ?></p>
                        <p><strong>PO Number:</strong> <?= htmlspecialchars($log['po_number']) ?></p>
                        <p><strong>Date Received:</strong> <?= date('M d, Y', strtotime($log['delivery_date'])) ?></p>
                    </div>
                    <div class="col-md-6">
                        <p><strong>Category:</strong> 
                            <?php if (!empty($log['category_name'])): ?>
                                <span class="badge bg-light text-dark">
                                    <?= htmlspecialchars($log['category_name']) ?>
                                </span>
                            <?php else: ?>
                                <span class="text-muted">Uncategorized</span>
                            <?php endif; ?>
                        </p>
                        <p><strong>Log Created:</strong> <?= date('M d, Y', strtotime($log['created_at'])) ?></p>
                    </div>
                </div>
                <?php if (!empty($log['notes'])): ?>
                    <div class="mt-3 pt-3 border-top">
                        <p><strong>Notes:</strong><br><?= nl2br(htmlspecialchars($log['notes'])) ?></p>
                    </div>
                <?php endif; ?>
            </div>
        </div>

        <!-- Pallet Photos Section - Always Show -->
        <div class="card mb-4 border-0 shadow-sm">
            <div class="card-header bg-white d-flex justify-content-between align-items-center">
                <?php if (!empty($receivingPhotos)): ?>
                    <button class="btn btn-sm btn-outline-secondary d-flex align-items-center gap-1" type="button"
                        data-bs-toggle="collapse"
                        data-bs-target="#palletPhotosCollapse"
                        aria-expanded="false"
                        aria-controls="palletPhotosCollapse">
                        <i class="bi bi-images"></i> Show/Hide Pallet Photos (<?= count($receivingPhotos) ?>)
                    </button>
                <?php else: ?>
                    <div class="d-flex align-items-center">
                        <i class="bi bi-images me-2 text-muted"></i>
                        <span class="text-muted">Pallet Photos</span>
                        <span class="badge bg-light text-dark ms-2">No photos yet</span>
                    </div>
                <?php endif; ?>
                
                <!-- UPDATED: Upload photo button with permission check -->
                <?php if (RoleHelper::hasPermission('upload_receiving_photos')): ?>
                    <a href="<?= BASE_URL ?>receiving/upload_photo?receiving_id=<?= urlencode($log['id']) ?>" 
                       class="btn btn-sm btn-outline-dark" data-permission="upload_receiving_photos">
                        <i class="fas fa-plus me-1"></i>Upload Photo
                    </a>
                <?php endif; ?>
            </div>

            <?php if (!empty($receivingPhotos)): ?>
                <div id="palletPhotosCollapse" class="collapse">
                    <div class="card-body">
                        <div class="row g-3">
                            <?php foreach ($receivingPhotos as $photo): ?>
                                <div class="col-6 col-md-4 col-lg-3">
                                    <div class="border rounded shadow-sm p-2 bg-light text-center position-relative">
                                        <a href="<?= BASE_URL ?>public/uploads/receiving/<?= htmlspecialchars($photo['file_path']) ?>" target="_blank">
                                            <img src="<?= BASE_URL ?>public/uploads/receiving/<?= htmlspecialchars($photo['file_path']) ?>" 
                                                 class="img-fluid rounded mb-2" style="max-height: 180px; object-fit: cover;">
                                        </a>
                                        <?php if (!empty($photo['caption'])): ?>
                                            <p class="text-muted small mb-0"><?= htmlspecialchars($photo['caption']) ?></p>
                                        <?php endif; ?>
                                    </div>
                                </div>
                            <?php endforeach; ?>
                        </div>
                    </div>
                </div>
            <?php else: ?>
                <div class="card-body text-center py-4">
                    <div class="text-muted">
                        <i class="fas fa-camera fa-2x mb-3"></i>
                        <p class="mb-0">No photos uploaded yet for this receiving log.</p>
                        <?php if (RoleHelper::hasPermission('upload_receiving_photos')): ?>
                            <small>Click "Upload Photo" above to add the first photo.</small>
                        <?php else: ?>
                            <small class="text-muted">Contact your administrator to get permission to upload photos.</small>
                        <?php endif; ?>
                    </div>
                </div>
            <?php endif; ?>
        </div>

        <div class="d-flex justify-content-between align-items-center mb-2">
            <h5 class="mb-0">
                Inventory Items 
                <?php if (!empty($inventoryItems)): ?>
                    <span class="badge bg-primary"><?= count($inventoryItems) ?></span>
                <?php endif; ?>
            </h5>
            
            <!-- UPDATED: Add inventory item button with permission check -->
            <?php if (RoleHelper::hasPermission('add_inventory')): ?>
                <a href="<?= BASE_URL ?>inventory/add?receiving_id=<?= urlencode($log['id']) ?>" 
                   class="btn btn-sm btn-dark" data-permission="add_inventory">
                    <i class="fas fa-plus me-1"></i>Add Item
                </a>
            <?php endif; ?>
        </div>

        <?php if (empty($inventoryItems)): ?>
            <div class="alert alert-info">
                <i class="fas fa-info-circle me-2"></i>
                No inventory items have been added to this receiving log yet.
                <?php if (RoleHelper::hasPermission('add_inventory')): ?>
                    <a href="<?= BASE_URL ?>inventory/add?receiving_id=<?= urlencode($log['id']) ?>" class="alert-link">Add the first item</a>.
                <?php else: ?>
                    <br><small class="text-muted">Contact your administrator to get permission to add inventory items.</small>
                <?php endif; ?>
            </div>
        <?php else: ?>
            <!-- Desktop Table -->
            <div class="table-responsive d-none d-lg-block">
                <table class="table table-bordered table-sm table-hover bg-white">
                    <thead class="table-light">
                        <tr>
                            <th>SKU</th>
                            <th>Product</th>
                            <th>Qty</th>
                            <th>Unit</th>
                            <th>Location</th>
                            <th>Expires</th>
                            <th>Notes</th>
                            <th>Logged</th>
                            <th>Actions</th>
                        </tr>
                    </thead>
                    <tbody>
                        <?php foreach ($inventoryItems as $item): ?>
                            <tr>
                                <td><?= htmlspecialchars($item['sku']) ?></td>
                                <td><?= htmlspecialchars($item['product_name']) ?></td>
                                <td><?= htmlspecialchars($item['quantity']) ?></td>
                                <td><?= htmlspecialchars($item['unit_type']) ?></td>
                                <td><?= htmlspecialchars($item['location']) ?></td>
                                <td><?= $item['expiration_date'] ? htmlspecialchars($item['expiration_date']) : '-' ?></td>
                                <td><?= htmlspecialchars(substr($item['notes'], 0, 50)) ?><?= strlen($item['notes']) > 50 ? '...' : '' ?></td>
                                <td><?= date('M d, Y', strtotime($item['created_at'])) ?></td>
                                <td>
                                    <!-- UPDATED: View button with optional edit/delete based on permissions -->
                                    <div class="d-flex gap-1 flex-wrap">
                                        <a href="<?= BASE_URL ?>inventory/view?id=<?= urlencode($item['id']) ?>&from_receiving=<?= urlencode($receiving_id) ?>" 
                                           class="btn btn-sm btn-outline-primary">
                                            <i class="fas fa-eye me-1"></i>View
                                        </a>
                                        
                                        <?php if (RoleHelper::hasPermission('edit_inventory')): ?>
                                            <a href="<?= BASE_URL ?>inventory/edit?id=<?= urlencode($item['id']) ?>&from_receiving=<?= urlencode($receiving_id) ?>" 
                                               class="btn btn-sm btn-outline-secondary" data-permission="edit_inventory">
                                                <i class="fas fa-edit me-1"></i>Edit
                                            </a>
                                        <?php endif; ?>
                                    </div>
                                </td>
                            </tr>
                        <?php endforeach; ?>
                    </tbody>
                </table>
            </div>

            <!-- Mobile Card View -->
            <div class="d-block d-lg-none">
                <?php foreach ($inventoryItems as $item): ?>
                    <div class="card mb-3 shadow-sm">
                        <div class="card-body">
                            <h6 class="card-title"><?= htmlspecialchars($item['product_name']) ?></h6>
                            <p class="mb-1"><strong>SKU:</strong> <?= htmlspecialchars($item['sku']) ?></p>
                            <p class="mb-1"><strong>Qty:</strong> <?= htmlspecialchars($item['quantity']) ?> <?= htmlspecialchars($item['unit_type']) ?></p>
                            <p class="mb-1"><strong>Location:</strong> <?= htmlspecialchars($item['location']) ?></p>
                            <p class="mb-1"><strong>Expires:</strong> <?= $item['expiration_date'] ?: '-' ?></p>
                            <?php if (!empty($item['notes'])): ?>
                                <p class="mb-1"><strong>Notes:</strong> <?= htmlspecialchars($item['notes']) ?></p>
                            <?php endif; ?>
                            <p class="mb-2"><strong>Logged:</strong> <?= date('M d, Y', strtotime($item['created_at'])) ?></p>
                            
                            <!-- UPDATED: Mobile action buttons with permission checks -->
                            <div class="d-flex gap-2 flex-wrap">
                                <a href="<?= BASE_URL ?>inventory/view?id=<?= urlencode($item['id']) ?>&from_receiving=<?= urlencode($receiving_id) ?>" 
                                   class="btn btn-sm btn-outline-primary flex-fill">
                                    <i class="fas fa-eye me-1"></i>View
                                </a>
                                
                                <?php if (RoleHelper::hasPermission('edit_inventory')): ?>
                                    <a href="<?= BASE_URL ?>inventory/edit?id=<?= urlencode($item['id']) ?>&from_receiving=<?= urlencode($receiving_id) ?>" 
                                       class="btn btn-sm btn-outline-secondary flex-fill" data-permission="edit_inventory">
                                        <i class="fas fa-edit me-1"></i>Edit
                                    </a>
                                <?php endif; ?>
                            </div>
                        </div>
                    </div>
                <?php endforeach; ?>
            </div>
        <?php endif; ?>

        <!-- Back Navigation -->
        <div class="mt-4 pt-3 border-top">
            <a href="<?= BASE_URL ?>receiving" class="btn btn-outline-secondary">
                <i class="fas fa-arrow-left me-1"></i>Back to Receiving Logs
            </a>
        </div>

    <?php endif; ?>
</div>

<!-- UPDATED: Custom CSS for responsive design and permission elements -->
<style>
/* Permission-protected elements styling */
[data-permission].permission-denied {
    opacity: 0.6;
    pointer-events: none;
    position: relative;
}

[data-permission].permission-denied::after {
    content: "\f023";
    font-family: "Font Awesome 5 Free";
    font-weight: 900;
    position: absolute;
    top: 50%;
    right: 8px;
    transform: translateY(-50%);
    color: #dc3545;
    font-size: 12px;
}

/* Mobile responsiveness improvements */
@media (max-width: 768px) {
    .d-flex.gap-2.flex-wrap {
        gap: 0.5rem !important;
    }
    
    .btn-sm {
        font-size: 0.775rem;
        padding: 0.25rem 0.5rem;
    }
    
    .flex-fill {
        flex: 1;
    }
}

/* Desktop action buttons */
@media (min-width: 992px) {
    .table td .d-flex {
        justify-content: flex-start;
    }
}
</style>

<?php include __DIR__ . '/../partials/footer.php'; ?>