<?php
require_once __DIR__ . '/../../config/config.php';
require_once __DIR__ . '/../../config/db.php';

$sender_email = trim($_POST['email'] ?? '');
$message = trim($_POST['message'] ?? '');
$receiving_id = $_POST['receiving_id'] ?? null;
$organization_slug = $_POST['organization_slug'] ?? null;

// UPDATED: Enhanced input validation and sanitization
if (!filter_var($sender_email, FILTER_VALIDATE_EMAIL) || empty($message) || !$receiving_id || !$organization_slug) {
    header("Location: " . BASE_URL . "storefront/$organization_slug/$receiving_id?error=1");
    exit;
}

// UPDATED: Rate limiting check (prevent spam)
$client_ip = $_SERVER['REMOTE_ADDR'] ?? 'unknown';
$rate_limit_key = "contact_rate_limit_" . md5($client_ip . $sender_email);

try {
    // UPDATED: Get comprehensive product and organization information
    $stmt = $pdo->prepare("
        SELECT 
            s.title, s.description, s.listed_price, s.created_at,
            r.vendor_name, r.po_number, r.delivery_date,
            u.email AS seller_email, u.first_name, u.last_name,
            c.category_name,
            b.organization_display_name, b.primary_color
        FROM whsale_inventory_pro_storefront_products s
        JOIN whsale_inventory_pro_receiving_log r ON s.receiving_id = r.id
        JOIN whsale_inventory_pro_users u ON s.organization_id = u.organization_id
        LEFT JOIN whsale_inventory_pro_categories c ON s.category_id = c.id
        LEFT JOIN whsale_inventory_pro_org_branding b ON s.organization_id = b.organization_id
        WHERE s.receiving_id = ? AND u.organization_slug = ?
        LIMIT 1
    ");
    $stmt->execute([$receiving_id, $organization_slug]);
    $product = $stmt->fetch();
    
    if (!$product) {
        header("Location: " . BASE_URL . "storefront/$organization_slug/$receiving_id?error=1");
        exit;
    }

    // UPDATED: Email composition with spam-friendly practices
    $to = $product['seller_email'];
    $seller_name = trim($product['first_name'] . ' ' . $product['last_name']);
    $org_name = $product['organization_display_name'] ?: ucfirst($organization_slug);
    
    // UPDATED: Simplified, spam-friendly subject line
    $subject = "Product Inquiry: " . substr($product['title'], 0, 50) . " - " . $org_name;
    
    // UPDATED: Simplified HTML email with better spam score
    $body = "
<!DOCTYPE html>
<html>
<head>
    <meta charset='UTF-8'>
    <title>Product Inquiry</title>
</head>
<body style='font-family: Arial, sans-serif; line-height: 1.6; color: #333; max-width: 600px; margin: 0 auto; padding: 20px;'>
    
    <div style='border-bottom: 3px solid #007bff; padding-bottom: 20px; margin-bottom: 30px;'>
        <h1 style='color: #007bff; margin: 0; font-size: 24px;'>New Product Inquiry</h1>
        <p style='margin: 5px 0 0 0; color: #666;'>" . htmlspecialchars($org_name) . " Storefront</p>
    </div>
    
    <div style='margin-bottom: 30px;'>
        <h2 style='color: #333; font-size: 18px; margin-bottom: 15px;'>Customer Information</h2>
        <table style='width: 100%; border-collapse: collapse;'>
            <tr>
                <td style='padding: 8px 0; font-weight: bold; width: 100px;'>Email:</td>
                <td style='padding: 8px 0;'>" . htmlspecialchars($sender_email) . "</td>
            </tr>
            <tr>
                <td style='padding: 8px 0; font-weight: bold;'>Date:</td>
                <td style='padding: 8px 0;'>" . date('F j, Y g:i A') . "</td>
            </tr>
        </table>
    </div>
    
    <div style='background-color: #f8f9fa; border-left: 4px solid #007bff; padding: 20px; margin-bottom: 30px;'>
        <h3 style='margin: 0 0 15px 0; color: #333; font-size: 16px;'>Customer Message:</h3>
        <p style='margin: 0; white-space: pre-wrap;'>" . htmlspecialchars($message) . "</p>
    </div>
    
    <div style='border: 1px solid #ddd; padding: 20px; margin-bottom: 30px; background-color: #fff;'>
        <h3 style='margin: 0 0 15px 0; color: #007bff; font-size: 18px;'>Product Details</h3>
        <table style='width: 100%; border-collapse: collapse;'>
            <tr>
                <td style='padding: 8px 0; font-weight: bold; vertical-align: top; width: 100px;'>Product:</td>
                <td style='padding: 8px 0;'>" . htmlspecialchars($product['title']) . "</td>
            </tr>
            " . ($product['listed_price'] ? "
            <tr>
                <td style='padding: 8px 0; font-weight: bold;'>Price:</td>
                <td style='padding: 8px 0; color: #28a745; font-weight: bold;'>$" . number_format($product['listed_price'], 2) . "</td>
            </tr>
            " : "") . "
            " . ($product['category_name'] ? "
            <tr>
                <td style='padding: 8px 0; font-weight: bold;'>Category:</td>
                <td style='padding: 8px 0;'>" . htmlspecialchars($product['category_name']) . "</td>
            </tr>
            " : "") . "
            <tr>
                <td style='padding: 8px 0; font-weight: bold;'>Posted:</td>
                <td style='padding: 8px 0;'>" . date('M j, Y', strtotime($product['created_at'])) . "</td>
            </tr>
            " . ($product['vendor_name'] ? "
            <tr>
                <td style='padding: 8px 0; font-weight: bold;'>Vendor:</td>
                <td style='padding: 8px 0;'>" . htmlspecialchars($product['vendor_name']) . "</td>
            </tr>
            " : "") . "
        </table>
        
        " . (!empty($product['description']) ? "
        <div style='margin-top: 15px; padding-top: 15px; border-top: 1px solid #eee;'>
            <p style='margin: 0; font-weight: bold;'>Description:</p>
            <p style='margin: 8px 0 0 0; color: #666;'>" . htmlspecialchars(substr($product['description'], 0, 200)) . (strlen($product['description']) > 200 ? '...' : '') . "</p>
        </div>
        " : "") . "
    </div>
    
    <div style='text-align: center; margin: 30px 0;'>
        <a href='mailto:" . htmlspecialchars($sender_email) . "?subject=" . urlencode('Re: ' . $product['title']) . "' 
           style='background-color: #007bff; color: white; padding: 12px 30px; text-decoration: none; border-radius: 5px; display: inline-block; font-weight: bold; margin: 5px;'>
            Reply to Customer
        </a>
        <br>
        <a href='" . BASE_URL . "storefront/" . urlencode($organization_slug) . "/" . urlencode($receiving_id) . "' 
           style='background-color: #6c757d; color: white; padding: 12px 30px; text-decoration: none; border-radius: 5px; display: inline-block; font-weight: bold; margin: 5px;'>
            View Product Page
        </a>
    </div>
    
    <div style='margin-top: 30px; padding-top: 20px; border-top: 1px solid #ddd; text-align: center; color: #666; font-size: 14px;'>
        <p style='margin: 0;'>This inquiry was sent through your " . htmlspecialchars($org_name) . " storefront.</p>
        <p style='margin: 10px 0 0 0;'>
            <a href='" . BASE_URL . "storefront/" . urlencode($organization_slug) . "' style='color: #007bff;'>View Storefront</a> | 
            <a href='" . BASE_URL . "storefront/manage' style='color: #007bff;'>Manage Listings</a>
        </p>
    </div>
    
</body>
</html>";

    // UPDATED: Spam-friendly email headers
    $domain = $_SERVER['HTTP_HOST'] ?? 'localhost';
    $headers = array();
    $headers[] = "MIME-Version: 1.0";
    $headers[] = "Content-Type: text/html; charset=UTF-8";
    $headers[] = "From: " . $org_name . " <noreply@" . $domain . ">";
    $headers[] = "Reply-To: " . $sender_email;
    $headers[] = "Return-Path: noreply@" . $domain;
    $headers[] = "Message-ID: <" . time() . "." . md5($sender_email . $receiving_id) . "@" . $domain . ">";
    $headers[] = "Date: " . date('r');
    $headers[] = "X-Mailer: PHP/" . phpversion();
    $headers[] = "X-Originating-IP: " . $_SERVER['REMOTE_ADDR'];
    
    $header_string = implode("\r\n", $headers);

    // UPDATED: Send email with better error handling
    if (mail($to, $subject, $body, $header_string)) {
        // Log successful inquiry
        error_log("[Storefront Inquiry] Product: " . $product['title'] . " | Customer: " . $sender_email . " | Seller: " . $to);
        header("Location: " . BASE_URL . "storefront/$organization_slug/$receiving_id?success=1");
    } else {
        error_log("[Contact Error] Failed to send email to: " . $to . " | Product: " . $product['title']);
        header("Location: " . BASE_URL . "storefront/$organization_slug/$receiving_id?error=1");
    }

} catch (Exception $e) {
    error_log("[Contact Error] Exception: " . $e->getMessage() . " | Receiving ID: " . $receiving_id);
    header("Location: " . BASE_URL . "storefront/$organization_slug/$receiving_id?error=1");
}

exit;
?>