<?php
require_once __DIR__ . '/../../config/config.php';
require_once __DIR__ . '/../../config/db.php';
require_once __DIR__ . '/../../helpers/AuthHelper.php';
require_once __DIR__ . '/../../helpers/RoleHelper.php';

// UPDATED: Require specific permission for editing storefront listings
AuthHelper::requirePermission('edit_storefront_listings');

$id = $_GET['id'] ?? null;
$error = '';
$success = '';
$product = null;
$organization_id = $_SESSION['organization_id'];

if (!$id || !is_numeric($id)) {
    header("Location: " . BASE_URL . "storefront/manage");
    exit;
}

// Fetch existing categories for this organization
$categories = [];
try {
    $stmt = $pdo->prepare("SELECT id, category_name FROM whsale_inventory_pro_categories WHERE organization_id = ? ORDER BY category_name ASC");
    $stmt->execute([$organization_id]);
    $categories = $stmt->fetchAll(PDO::FETCH_ASSOC);
} catch (Exception $e) {
    error_log("Error fetching categories: " . $e->getMessage());
}

try {
    // UPDATED: Enhanced security - verify product belongs to user's organization AND fetch payment fields
    $stmt = $pdo->prepare("
        SELECT sp.*, c.category_name, r.vendor_name, r.po_number, r.delivery_date
        FROM whsale_inventory_pro_storefront_products sp
        LEFT JOIN whsale_inventory_pro_categories c ON sp.category_id = c.id
        LEFT JOIN whsale_inventory_pro_receiving_log r ON sp.receiving_id = r.id
        WHERE sp.id = ? AND sp.organization_id = ?
    ");
    $stmt->execute([$id, $organization_id]);
    $product = $stmt->fetch();

    if (!$product) {
        throw new Exception("Product not found or you don't have permission to edit it.");
    }

    if ($_SERVER['REQUEST_METHOD'] === 'POST') {
        $title = trim($_POST['title'] ?? '');
        $description = trim($_POST['description'] ?? '');
        $listed_price = $_POST['listed_price'] !== '' ? (float)$_POST['listed_price'] : null;
        $is_active = isset($_POST['is_active']) ? 1 : 0;
        $category_id = $_POST['category_id'] ?? null;
        $new_category = trim($_POST['new_category'] ?? '');
        
        // UPDATED: Handle payment fields
        $payment_link = !empty($_POST['payment_link']) ? trim($_POST['payment_link']) : null;
        $payment_type = !empty($_POST['payment_type']) ? $_POST['payment_type'] : null;

        if (!$title || !$description) {
            $error = 'Title and description are required.';
        } else {
            // UPDATED: Validate payment link if provided (only if user has permission)
            if ($payment_link && RoleHelper::hasPermission('manage_payment_links')) {
                if (!filter_var($payment_link, FILTER_VALIDATE_URL)) {
                    $error = 'Invalid payment link URL format.';
                } elseif (!str_starts_with($payment_link, 'https://')) {
                    $error = 'Payment links must use HTTPS for security.';
                }
            } elseif ($payment_link && !RoleHelper::hasPermission('manage_payment_links')) {
                // Clear payment fields if user doesn't have permission
                $payment_link = null;
                $payment_type = null;
            }
            
            if (!$error) {
                try {
                    $pdo->beginTransaction();

                    // Handle category logic
                    $final_category_id = null;
                    
                    if (!empty($new_category)) {
                        // UPDATED: Enhanced security - verify user can create categories in their organization
                        $stmt = $pdo->prepare("INSERT IGNORE INTO whsale_inventory_pro_categories (organization_id, category_name) VALUES (?, ?)");
                        $stmt->execute([$organization_id, $new_category]);
                        
                        // Get the category ID (whether newly created or existing)
                        $stmt = $pdo->prepare("SELECT id FROM whsale_inventory_pro_categories WHERE organization_id = ? AND category_name = ?");
                        $stmt->execute([$organization_id, $new_category]);
                        $final_category_id = $stmt->fetchColumn();
                    } elseif (!empty($category_id) && $category_id !== '') {
                        // UPDATED: Enhanced security - verify category belongs to user's organization
                        $stmt = $pdo->prepare("SELECT id FROM whsale_inventory_pro_categories WHERE id = ? AND organization_id = ?");
                        $stmt->execute([$category_id, $organization_id]);
                        if ($stmt->fetchColumn()) {
                            $final_category_id = $category_id;
                        }
                    }
                    // If both are empty, $final_category_id remains null (no category)

                    // UPDATED: Enhanced security - update only products belonging to user's organization WITH payment fields
                    $updateStmt = $pdo->prepare("
                        UPDATE whsale_inventory_pro_storefront_products 
                        SET title = ?, description = ?, listed_price = ?, is_active = ?, category_id = ?, 
                            payment_link = ?, payment_type = ?, updated_at = NOW()
                        WHERE id = ? AND organization_id = ?
                    ");
                    $updateStmt->execute([$title, $description, $listed_price, $is_active, $final_category_id, 
                                        $payment_link, $payment_type, $id, $organization_id]);

                    $pdo->commit();

                    // Refresh categories list in case a new one was added
                    $stmt = $pdo->prepare("SELECT id, category_name FROM whsale_inventory_pro_categories WHERE organization_id = ? ORDER BY category_name ASC");
                    $stmt->execute([$organization_id]);
                    $categories = $stmt->fetchAll(PDO::FETCH_ASSOC);

                    // Refresh product data
                    $stmt = $pdo->prepare("
                        SELECT sp.*, c.category_name, r.vendor_name, r.po_number, r.delivery_date
                        FROM whsale_inventory_pro_storefront_products sp
                        LEFT JOIN whsale_inventory_pro_categories c ON sp.category_id = c.id
                        LEFT JOIN whsale_inventory_pro_receiving_log r ON sp.receiving_id = r.id
                        WHERE sp.id = ? AND sp.organization_id = ?
                    ");
                    $stmt->execute([$id, $organization_id]);
                    $product = $stmt->fetch();

                    $success = "Product updated successfully.";
                } catch (Exception $e) {
                    $pdo->rollback();
                    $error = "Update failed: " . $e->getMessage();
                }
            }
        }
    }
} catch (Exception $e) {
    $error = $e->getMessage();
}
?>

<?php include __DIR__ . '/../partials/head.php'; ?>

<div class="container mt-4 mb-5">
    <div class="row justify-content-center">
        <div class="col-12 col-lg-8">
            <div class="d-flex align-items-center mb-4">
                <h4 class="mb-0 me-3">
                    <i class="fas fa-edit me-2"></i>Edit Storefront Product
                </h4>
                <div class="ms-auto">
                    <?= RoleHelper::getRoleBadge() ?>
                </div>
            </div>

            <?php if ($error): ?>
                <div class="alert alert-danger">
                    <i class="fas fa-exclamation-circle me-2"></i>
                    <?= htmlspecialchars($error) ?>
                </div>
            <?php endif; ?>

            <?php if ($success): ?>
                <div class="alert alert-success">
                    <i class="fas fa-check-circle me-2"></i>
                    <?= htmlspecialchars($success) ?>
                </div>
            <?php endif; ?>

            <?php if ($product): ?>
                
                <!-- Product Context Information -->
                <div class="card mb-4 shadow-sm">
                    <div class="card-header bg-light">
                        <h6 class="mb-0">
                            <i class="fas fa-info-circle me-2"></i>Product Context
                        </h6>
                    </div>
                    <div class="card-body">
                        <div class="row">
                            <div class="col-md-6">
                                <p class="mb-1"><strong>Receiving ID:</strong> #<?= htmlspecialchars($product['receiving_id']) ?></p>
                                <p class="mb-1"><strong>Vendor:</strong> <?= htmlspecialchars($product['vendor_name']) ?></p>
                            </div>
                            <div class="col-md-6">
                                <p class="mb-1"><strong>PO Number:</strong> <?= htmlspecialchars($product['po_number']) ?></p>
                                <p class="mb-1"><strong>Delivery Date:</strong> <?= date('M d, Y', strtotime($product['delivery_date'])) ?></p>
                            </div>
                        </div>
                    </div>
                </div>

                <!-- Edit Form -->
                <div class="card shadow-sm">
                    <div class="card-header bg-primary text-white">
                        <h6 class="mb-0">
                            <i class="fas fa-edit me-2"></i>Edit Product Details
                        </h6>
                    </div>
                    <div class="card-body">
                        <form method="POST" action="<?= BASE_URL ?>storefront/manage/edit">
    <input type="hidden" name="product_id" value="<?= htmlspecialchars($product['id']) ?>">
                            <div class="mb-3">
                                <label for="title" class="form-label">
                                    <i class="fas fa-heading me-1"></i>Product Title <span class="text-danger">*</span>
                                </label>
                                <input type="text" name="title" id="title" class="form-control" 
                                       value="<?= htmlspecialchars($product['title']) ?>" required
                                       placeholder="Enter an attractive title for your product">
                            </div>

                            <div class="mb-3">
                                <label for="description" class="form-label">
                                    <i class="fas fa-align-left me-1"></i>Description <span class="text-danger">*</span>
                                </label>
                                <textarea name="description" id="description" class="form-control" rows="4" required
                                          placeholder="Provide detailed product information..."><?= htmlspecialchars($product['description']) ?></textarea>
                            </div>

                            <div class="row">
                                <div class="col-md-6 mb-3">
                                    <label for="listed_price" class="form-label">
                                        <i class="fas fa-dollar-sign me-1"></i>Listed Price
                                    </label>
                                    <div class="input-group">
                                        <span class="input-group-text">$</span>
                                        <input type="number" step="0.01" name="listed_price" id="listed_price" 
                                               class="form-control" value="<?= htmlspecialchars($product['listed_price']) ?>"
                                               placeholder="0.00" min="0">
                                    </div>
                                    <div class="form-text">Leave blank for "Contact for pricing"</div>
                                </div>

                                <div class="col-md-6 mb-3">
                                    <label for="category" class="form-label">
                                        <i class="fas fa-tag me-1"></i>Category
                                    </label>
                                    <div class="category-selector">
                                        <!-- Existing Category Dropdown -->
                                        <select name="category_id" id="categorySelect" class="form-select mb-2">
                                            <option value="">Select category (optional)</option>
                                            <?php foreach ($categories as $category): ?>
                                                <option value="<?= $category['id'] ?>" 
                                                        <?= ($product['category_id'] == $category['id']) ? 'selected' : '' ?>>
                                                    <?= htmlspecialchars($category['category_name']) ?>
                                                </option>
                                            <?php endforeach; ?>
                                        </select>
                                        
                                        <!-- OR divider -->
                                        <div class="text-center text-muted small mb-2">
                                            <span class="px-2 bg-white">OR</span>
                                            <hr class="mt-0" style="margin-top: -12px; z-index: -1;">
                                        </div>
                                        
                                        <!-- New Category Input -->
                                        <div class="input-group">
                                            <input type="text" name="new_category" id="newCategoryInput" class="form-control" 
                                                   placeholder="Create new category..." maxlength="100">
                                            <button type="button" class="btn btn-outline-secondary" id="clearCategoryBtn" 
                                                    onclick="clearCategorySelection()" title="Clear selection">
                                                <i class="fas fa-times"></i>
                                            </button>
                                        </div>
                                        
                                        <div class="form-text">
                                            <i class="fas fa-info-circle me-1"></i>
                                            Current: <?= !empty($product['category_name']) ? htmlspecialchars($product['category_name']) : 'Uncategorized' ?>
                                        </div>
                                    </div>
                                </div>
                            </div>

                            <!-- UPDATED: Payment Integration Section (only show if user has permission) -->
                            <?php if (RoleHelper::hasPermission('manage_payment_links')): ?>
                            <div class="card mt-4 mb-4">
                                <div class="card-header bg-success text-white">
                                    <h6 class="mb-0"><i class="fas fa-credit-card me-2"></i>Online Payment Integration</h6>
                                </div>
                                <div class="card-body">
                                    <div class="row">
                                        <div class="col-md-6 mb-3">
                                            <label for="payment_type" class="form-label">Payment Type</label>
                                            <select class="form-select" id="payment_type" name="payment_type">
                                                <option value="">No Online Payment</option>
                                                <option value="stripe" <?= ($product['payment_type'] ?? '') === 'stripe' ? 'selected' : '' ?>>Stripe</option>
                                                <option value="paypal" <?= ($product['payment_type'] ?? '') === 'paypal' ? 'selected' : '' ?>>PayPal</option>
                                                <option value="square" <?= ($product['payment_type'] ?? '') === 'square' ? 'selected' : '' ?>>Square</option>
                                                <option value="custom" <?= ($product['payment_type'] ?? '') === 'custom' ? 'selected' : '' ?>>Other/Custom</option>
                                            </select>
                                            <div class="form-text">Select the payment processor you're using</div>
                                        </div>
                                        
                                        <div class="col-md-6 mb-3">
                                            <label for="payment_link" class="form-label">Payment Link</label>
                                            <input type="url" class="form-control" id="payment_link" name="payment_link" 
                                                   value="<?= htmlspecialchars($product['payment_link'] ?? '') ?>"
                                                   placeholder="https://buy.stripe.com/... or https://paypal.me/...">
                                            <div class="form-text">
                                                <i class="fas fa-info-circle"></i> Must use HTTPS for security
                                            </div>
                                        </div>
                                    </div>

                                    <?php if (!empty($product['payment_link'])): ?>
                                    <div class="alert alert-info mb-3">
                                        <i class="fas fa-shopping-cart"></i> 
                                        <strong>Payment Link Active:</strong> Customers will see a "Buy Now" button on your storefront
                                    </div>
                                    <?php endif; ?>

                                    <div class="alert alert-warning mb-0">
                                        <i class="fas fa-shield-alt"></i> 
                                        <strong>Security Note:</strong> Only use payment links from trusted payment processors. Links must use HTTPS.
                                    </div>
                                </div>
                            </div>
                            <?php endif; ?>

                            <div class="mb-4">
                                <div class="form-check">
                                    <input type="checkbox" name="is_active" id="is_active" class="form-check-input" 
                                           <?= $product['is_active'] ? 'checked' : '' ?>>
                                    <label for="is_active" class="form-check-label">
                                        <i class="fas fa-eye me-1"></i>Active Listing
                                    </label>
                                    <div class="form-text">Uncheck to hide this product from your storefront</div>
                                </div>
                            </div>

                            <div class="d-flex gap-2 justify-content-end">
                                <a href="<?= BASE_URL ?>storefront/manage" class="btn btn-outline-secondary">
                                    <i class="fas fa-times me-1"></i>Cancel
                                </a>
                                <button type="submit" class="btn btn-primary">
                                    <i class="fas fa-save me-1"></i>Save Changes
                                </button>
                            </div>
                        </form>
                    </div>
                </div>

                <!-- Quick Actions -->
                <div class="mt-3 text-center">
                    <a href="<?= BASE_URL ?>storefront/<?= urlencode($_SESSION['organization_slug'] ?? 'preview') ?>/<?= urlencode($product['receiving_id']) ?>" 
                       class="btn btn-outline-info btn-sm me-2" target="_blank">
                        <i class="fas fa-external-link-alt me-1"></i>Preview on Storefront
                    </a>
                    <a href="<?= BASE_URL ?>receiving/view?id=<?= urlencode($product['receiving_id']) ?>" 
                       class="btn btn-outline-secondary btn-sm">
                        <i class="fas fa-truck me-1"></i>View Receiving Log
                    </a>
                </div>

            <?php endif; ?>
        </div>
    </div>
</div>

<!-- Custom CSS for Category Selector and Payment Section -->
<style>
.category-selector {
    position: relative;
}

.category-selector .form-select:focus,
.category-selector .form-control:focus {
    border-color: #0d6efd;
    box-shadow: 0 0 0 0.2rem rgba(13, 110, 253, 0.25);
}

.category-selector hr {
    position: relative;
    border-color: #dee2e6;
}

.category-selector .text-muted span {
    position: relative;
    z-index: 1;
}

#clearCategoryBtn {
    border-left: none;
}

.input-group .form-control:focus + .btn {
    border-color: #0d6efd;
    box-shadow: 0 0 0 0.2rem rgba(13, 110, 253, 0.25);
}

/* Mobile responsiveness improvements */
@media (max-width: 768px) {
    .d-flex.gap-2 {
        flex-direction: column;
        gap: 0.75rem !important;
    }
    
    .btn {
        text-align: center;
    }
    
    .btn-sm {
        font-size: 0.875rem;
        padding: 0.375rem 0.75rem;
    }
}

/* Card styling improvements */
.card.shadow-sm {
    box-shadow: 0 0.125rem 0.25rem rgba(0, 0, 0, 0.075);
    border: 1px solid rgba(0, 0, 0, 0.125);
}

.card-header {
    border-bottom: 1px solid rgba(0, 0, 0, 0.125);
}

/* Form improvements */
.form-control:focus,
.form-select:focus {
    border-color: #0d6efd;
    box-shadow: 0 0 0 0.2rem rgba(13, 110, 253, 0.25);
}

.form-text {
    font-size: 0.875rem;
    color: #6c757d;
}

/* Alert styling */
.alert {
    border: none;
    border-radius: 8px;
}
</style>

<!-- JavaScript for Category Selection and Payment Validation -->
<script>
// Handle category selection logic
document.addEventListener('DOMContentLoaded', function() {
    const categorySelect = document.getElementById('categorySelect');
    const newCategoryInput = document.getElementById('newCategoryInput');
    
    // When user selects an existing category, clear the new category input
    categorySelect.addEventListener('change', function() {
        if (this.value) {
            newCategoryInput.value = '';
        }
    });
    
    // When user types in new category, clear the existing category selection
    newCategoryInput.addEventListener('input', function() {
        if (this.value) {
            categorySelect.value = '';
        }
    });
    
    // Payment link validation
    const paymentLinkInput = document.getElementById('payment_link');
    const paymentTypeSelect = document.getElementById('payment_type');
    
    if (paymentLinkInput && paymentTypeSelect) {
        // Validate payment link format
        paymentLinkInput.addEventListener('input', function() {
            const link = this.value.trim();
            
            if (link && !link.startsWith('https://')) {
                this.setCustomValidity('Payment links must use HTTPS for security');
            } else {
                this.setCustomValidity('');
            }
        });
        
        // Clear payment link when payment type is set to none
        paymentTypeSelect.addEventListener('change', function() {
            if (this.value === '') {
                paymentLinkInput.value = '';
            }
        });
        
        // Clear payment type when payment link is cleared
        paymentLinkInput.addEventListener('input', function() {
            if (this.value.trim() === '') {
                paymentTypeSelect.value = '';
            }
        });
    }
});

// Clear both category selections
function clearCategorySelection() {
    document.getElementById('categorySelect').value = '';
    document.getElementById('newCategoryInput').value = '';
}
</script>

<?php include __DIR__ . '/../partials/footer.php'; ?>