<?php
require_once __DIR__ . '/../../config/config.php';
require_once __DIR__ . '/../../config/db.php';

if (!isset($products) || !is_array($products)) {
    http_response_code(500);
    echo "Products not loaded.";
    exit;
}

if (!isset($organization_slug)) {
    http_response_code(500);
    echo "Missing organization slug.";
    exit;
}

// Fetch logo path, display name, and color scheme
$orgDisplayName = '';
$logoPath = null;
$primaryColor = '#f66903';
$secondaryColor = '#ff9e49';
$navbarBgColor = '#ffffff';
$navbarTextColor = '#000000';
$bodyBgColor = '#f8f9fa';
$priceColor = '#198754';
$headingColor = '#212529';
$bodyTextColor = '#212529';
$mutedTextColor = '#6c757d';
$cardBgColor = '#ffffff';
$cardBorderColor = '#dee2e6';
$linkColor = '#0d6efd';

// Fetch categories and organization info
$categories = [];
$organizationId = null;

try {
    $stmt = $pdo->prepare("
        SELECT 
            b.logo_path, b.organization_display_name, b.primary_color, b.secondary_color, 
            b.navbar_bg_color, b.navbar_text_color, b.body_bg_color, b.price_color,
            b.heading_color, b.body_text_color, b.muted_text_color, b.card_bg_color, 
            b.card_border_color, b.link_color,
            o.organization_slug, o.organization_id
        FROM whsale_inventory_pro_organizations o
        LEFT JOIN whsale_inventory_pro_org_branding b ON o.organization_id = b.organization_id
        WHERE o.organization_slug = ? 
        LIMIT 1
    ");
    $stmt->execute([$organization_slug]);
    $result = $stmt->fetch(PDO::FETCH_ASSOC);

    if ($result) {
        $organizationId = $result['organization_id'];
        
        // Use branding data if it exists, otherwise use defaults
        $logoPath = !empty($result['logo_path']) ? BASE_URL . 'public/uploads/logos/' . htmlspecialchars($result['logo_path']) : null;
        $orgDisplayName = $result['organization_display_name'] ?? ucfirst($result['organization_slug']);
        $primaryColor = $result['primary_color'] ?: $primaryColor;
        $secondaryColor = $result['secondary_color'] ?: $secondaryColor;
        $navbarBgColor = $result['navbar_bg_color'] ?: $navbarBgColor;
        $navbarTextColor = $result['navbar_text_color'] ?: $navbarTextColor;
        $bodyBgColor = $result['body_bg_color'] ?: $bodyBgColor;
        $priceColor = $result['price_color'] ?: $priceColor;
        $headingColor = $result['heading_color'] ?: $headingColor;
        $bodyTextColor = $result['body_text_color'] ?: $bodyTextColor;
        $mutedTextColor = $result['muted_text_color'] ?: $mutedTextColor;
        $cardBgColor = $result['card_bg_color'] ?: $cardBgColor;
        $cardBorderColor = $result['card_border_color'] ?: $cardBorderColor;
        $linkColor = $result['link_color'] ?: $linkColor;
    }

    // Fetch categories for this organization that have products in storefront
    if ($organizationId) {
        $stmt = $pdo->prepare("
            SELECT DISTINCT c.id, c.category_name, COUNT(sp.id) as product_count
            FROM whsale_inventory_pro_categories c
            INNER JOIN whsale_inventory_pro_storefront_products sp ON c.id = sp.category_id
            WHERE c.organization_id = ?
            GROUP BY c.id, c.category_name
            ORDER BY c.category_name ASC
        ");
        $stmt->execute([$organizationId]);
        $categories = $stmt->fetchAll(PDO::FETCH_ASSOC);
    }
} catch (Exception $e) {
    error_log("Storefront branding fetch failed: " . $e->getMessage());
}

// Handle category filtering
$selectedCategory = $_GET['category'] ?? '';
$filteredProducts = $products;

if (!empty($selectedCategory)) {
    if ($selectedCategory === 'uncategorized') {
        // Filter for products without category
        $filteredProducts = array_filter($products, function($product) {
            return empty($product['category_id']);
        });
    } else {
        // Filter for specific category
        $filteredProducts = array_filter($products, function($product) use ($selectedCategory) {
            return $product['category_id'] == $selectedCategory;
        });
    }
}
?>

<!DOCTYPE html>
<html lang="en">
<head>
    <meta charset="UTF-8">
    <title><?= htmlspecialchars($orgDisplayName ?: ucfirst($organization_slug)) ?> Storefront</title>
    <meta name="viewport" content="width=device-width, initial-scale=1">
    <link href="https://cdn.jsdelivr.net/npm/bootstrap@5.3.3/dist/css/bootstrap.min.css" rel="stylesheet">
    <link rel="stylesheet" href="https://cdnjs.cloudflare.com/ajax/libs/font-awesome/6.0.0/css/all.min.css">

    <style>
        body {
            background-color: <?= htmlspecialchars($bodyBgColor) ?>;
            color: <?= htmlspecialchars($bodyTextColor) ?>;
            padding-top: env(safe-area-inset-top, 60px);
        }

        .navbar-custom {
            background-color: <?= htmlspecialchars($navbarBgColor) ?> !important;
        }

        .navbar-custom .navbar-brand {
            color: <?= htmlspecialchars($navbarTextColor) ?> !important;
        }

        .org-logo {
            max-height: 80px;
            max-width: 250px;
            object-fit: contain;
            transition: all 0.3s ease;
        }

        /* Responsive logo sizing */
        @media (min-width: 992px) {
            .org-logo {
                max-height: 100px;
                max-width: 350px;
            }
        }

        @media (min-width: 1200px) {
            .org-logo {
                max-height: 120px;
                max-width: 400px;
            }
        }

        @media (max-width: 991px) and (min-width: 768px) {
            .org-logo {
                max-height: 70px;
                max-width: 200px;
            }
        }

        @media (max-width: 767px) and (min-width: 576px) {
            .org-logo {
                max-height: 60px;
                max-width: 180px;
            }
        }

        @media (max-width: 575px) {
            .org-logo {
                max-height: 50px;
                max-width: 150px;
            }
            
            .navbar {
                padding: 0.5rem 0;
            }
        }

        @media (max-width: 400px) {
            .org-logo {
                max-height: 40px;
                max-width: 120px;
            }
        }

        .product-card {
            transition: transform 0.2s ease, box-shadow 0.2s ease;
            display: flex;
            flex-direction: column;
            height: 100%;
            background-color: <?= htmlspecialchars($cardBgColor) ?>;
            border: 1px solid <?= htmlspecialchars($cardBorderColor) ?>;
        }

        .product-card:hover {
            transform: translateY(-6px);
            box-shadow: 0 1rem 1.5rem rgba(0, 0, 0, 0.15);
        }

        .product-card .card-img-top {
            object-fit: cover;
            height: 180px;
            width: 100%;
        }

        .product-card .card-body {
            flex-grow: 1;
            display: flex;
            flex-direction: column;
        }

        .product-card .card-title,
        .card-title,
        h1, h2, h3, h4, h5, h6 {
            color: <?= htmlspecialchars($headingColor) ?> !important;
        }

        .card-text {
            min-height: 60px;
            font-size: 0.9rem;
            color: <?= htmlspecialchars($bodyTextColor) ?> !important;
        }

        .product-price {
            color: <?= htmlspecialchars($priceColor) ?> !important;
            font-weight: bold;
        }

        .btn-outline-primary {
            color: <?= htmlspecialchars($primaryColor) ?>;
            border-color: <?= htmlspecialchars($primaryColor) ?>;
        }

        .btn-outline-primary:hover {
            background-color: <?= htmlspecialchars($primaryColor) ?>;
            color: white;
            border-color: <?= htmlspecialchars($primaryColor) ?>;
        }

        .card-footer {
            background-color: <?= htmlspecialchars($cardBgColor) ?> !important;
            border-top: 1px solid <?= htmlspecialchars($cardBorderColor) ?> !important;
            color: <?= htmlspecialchars($mutedTextColor) ?> !important;
        }

        .text-muted {
            color: <?= htmlspecialchars($mutedTextColor) ?> !important;
        }

        /* Category filter styling */
        .category-filter {
            background-color: rgba(255, 255, 255, 0.95);
            backdrop-filter: blur(10px);
            border-radius: 0.5rem;
            border: 1px solid <?= htmlspecialchars($cardBorderColor) ?>;
            margin-bottom: 2rem;
        }

        .category-pill {
            background-color: <?= htmlspecialchars($cardBgColor) ?>;
            border: 1px solid <?= htmlspecialchars($cardBorderColor) ?>;
            color: <?= htmlspecialchars($bodyTextColor) ?>;
            transition: all 0.2s ease;
        }

        .category-pill:hover {
            background-color: <?= htmlspecialchars($primaryColor) ?>;
            border-color: <?= htmlspecialchars($primaryColor) ?>;
            color: white;
        }

        .category-pill.active {
            background-color: <?= htmlspecialchars($primaryColor) ?>;
            border-color: <?= htmlspecialchars($primaryColor) ?>;
            color: white;
        }

        /* Search navbar styling */
        .search-toggle {
            border: none !important;
            background: none !important;
            transition: all 0.3s ease;
        }

        .search-toggle:hover {
            transform: scale(1.1);
        }

        .search-toggle:focus {
            box-shadow: none !important;
        }

        .search-container-navbar {
            transition: all 0.3s ease;
            overflow: hidden;
        }

        .search-container-navbar.show {
            animation: slideInRight 0.3s ease-out;
        }

        .navbar-search-input {
            border: 1px solid <?= htmlspecialchars($cardBorderColor) ?>;
            background-color: <?= htmlspecialchars($cardBgColor) ?>;
            color: <?= htmlspecialchars($bodyTextColor) ?>;
            min-width: 250px;
            transition: all 0.3s ease;
        }

        .navbar-search-input:focus {
            border-color: <?= htmlspecialchars($primaryColor) ?>;
            box-shadow: 0 0 0 0.2rem rgba(<?= 
                implode(', ', array_map(function($c) { 
                    return hexdec(substr($c, 1, 2)); 
                }, [substr($primaryColor, 1, 2), substr($primaryColor, 3, 2), substr($primaryColor, 5, 2)])) 
            ?>, 0.25);
            background-color: <?= htmlspecialchars($cardBgColor) ?>;
        }

        .navbar-search-input::placeholder {
            color: <?= htmlspecialchars($mutedTextColor) ?>;
        }

        .search-close {
            border-color: <?= htmlspecialchars($cardBorderColor) ?>;
            color: <?= htmlspecialchars($mutedTextColor) ?>;
            background-color: <?= htmlspecialchars($cardBgColor) ?>;
        }

        .search-close:hover {
            background-color: <?= htmlspecialchars($primaryColor) ?>;
            border-color: <?= htmlspecialchars($primaryColor) ?>;
            color: white;
        }

        @keyframes slideInRight {
            from {
                transform: translateX(100%);
                opacity: 0;
            }
            to {
                transform: translateX(0);
                opacity: 1;
            }
        }

        @media (max-width: 768px) {
            .navbar-search-input {
                min-width: 200px;
            }
        }

        @media (max-width: 576px) {
            .navbar-search-input {
                min-width: 150px;
                font-size: 0.9rem;
            }
            
            .search-toggle i {
                font-size: 1rem;
            }

            .card-text {
                min-height: auto;
            }
        }
    </style>
</head>
<body>

<nav class="navbar navbar-expand-lg navbar-custom shadow-sm sticky-top">
  <div class="container d-flex align-items-center">
    <a class="navbar-brand fw-bold d-flex align-items-center" href="#">
        <?php if ($logoPath): ?>
            <img src="<?= $logoPath ?>" alt="Store Logo" class="org-logo">
        <?php else: ?>
            <span class="fw-bold"><?= htmlspecialchars($orgDisplayName ?: ucfirst($organization_slug)) ?></span>
        <?php endif; ?>
    </a>
    
    <!-- Search Toggle and Search Bar -->
    <div class="d-flex align-items-center ms-auto">
        <!-- Search Toggle Button -->
        <button class="btn btn-link p-2 search-toggle" type="button" id="searchToggle" aria-label="Toggle search">
            <i class="fas fa-search" style="color: <?= htmlspecialchars($navbarTextColor) ?>; font-size: 1.1rem;"></i>
        </button>
        
        <!-- Collapsible Search Bar -->
        <div class="search-container-navbar collapse" id="navbarSearch">
            <div class="input-group">
                <input type="text" id="searchInput" class="form-control navbar-search-input" placeholder="Search products..." aria-label="Search products">
                <button class="btn btn-outline-secondary search-close" type="button" id="searchClose" aria-label="Close search">
                    <i class="fas fa-times"></i>
                </button>
            </div>
        </div>
    </div>
  </div>
</nav>

<!-- Category Filter Section -->
<?php if (!empty($categories) || !empty($selectedCategory)): ?>
<div class="container mt-4">
    <div class="category-filter p-3">
        <h6 class="mb-3">
            <i class="fas fa-filter me-2"></i>Filter by Category
        </h6>
        <div class="d-flex flex-wrap gap-2">
            <!-- All Categories -->
            <a href="<?= BASE_URL ?>storefront/<?= urlencode($organization_slug) ?>" 
               class="btn btn-sm category-pill <?= empty($selectedCategory) ? 'active' : '' ?>">
                <i class="fas fa-th-large me-1"></i>All Products
                <?php if (empty($selectedCategory)): ?>
                    <span class="badge bg-light text-dark ms-1"><?= count($products) ?></span>
                <?php endif; ?>
            </a>
            
            <!-- Uncategorized -->
            <?php 
            $uncategorizedCount = count(array_filter($products, function($p) { return empty($p['category_id']); }));
            if ($uncategorizedCount > 0): 
            ?>
                <a href="<?= BASE_URL ?>storefront/<?= urlencode($organization_slug) ?>?category=uncategorized" 
                   class="btn btn-sm category-pill <?= $selectedCategory === 'uncategorized' ? 'active' : '' ?>">
                    <i class="fas fa-tag me-1"></i>Uncategorized
                    <span class="badge bg-light text-dark ms-1"><?= $uncategorizedCount ?></span>
                </a>
            <?php endif; ?>
            
            <!-- Category Pills -->
            <?php foreach ($categories as $category): ?>
                <a href="<?= BASE_URL ?>storefront/<?= urlencode($organization_slug) ?>?category=<?= urlencode($category['id']) ?>" 
                   class="btn btn-sm category-pill <?= $selectedCategory == $category['id'] ? 'active' : '' ?>">
                    <i class="fas fa-tag me-1"></i><?= htmlspecialchars($category['category_name']) ?>
                    <span class="badge bg-light text-dark ms-1"><?= $category['product_count'] ?></span>
                </a>
            <?php endforeach; ?>
        </div>
    </div>
</div>
<?php endif; ?>

<div class="container mt-4 pb-5">
    <?php if (empty($filteredProducts)): ?>
        <div class="text-center py-5">
            <i class="fas fa-box-open fa-3x text-muted mb-3"></i>
            <h5 class="text-muted">No products found</h5>
            <p class="text-muted">
                <?php if (!empty($selectedCategory)): ?>
                    No products available in this category.
                    <a href="<?= BASE_URL ?>storefront/<?= urlencode($organization_slug) ?>" class="text-decoration-none">
                        View all products
                    </a>
                <?php else: ?>
                    Check back later for new products.
                <?php endif; ?>
            </p>
        </div>
    <?php else: ?>
        <div class="row g-4">
            <?php foreach ($filteredProducts as $product): ?>
                <?php
                    $photoStmt = $pdo->prepare("
                        SELECT file_path 
                        FROM whsale_inventory_pro_receiving_photos 
                        WHERE receiving_id = ? 
                        ORDER BY uploaded_at ASC 
                        LIMIT 1
                    ");
                    $photoStmt->execute([$product['receiving_id']]);
                    $photo = $photoStmt->fetch(PDO::FETCH_ASSOC);
                ?>
                <div class="col-12 col-sm-6 col-md-4 col-lg-3 product-card-wrapper">
                    <div class="card shadow-sm product-card">
                        <?php if ($photo): ?>
                            <img src="<?= BASE_URL ?>public/uploads/receiving/<?= htmlspecialchars($photo['file_path']) ?>" class="card-img-top" alt="Product Image">
                        <?php else: ?>
                            <div class="card-img-top bg-light d-flex align-items-center justify-content-center" style="height: 180px;">
                                <span class="text-muted small">No Image</span>
                            </div>
                        <?php endif; ?>
                        <div class="card-body d-flex flex-column">
                            <div class="d-flex justify-content-between align-items-start mb-2">
                                <h6 class="card-title mb-0 flex-grow-1"><?= htmlspecialchars($product['title']) ?></h6>
                                <?php if (!empty($product['category_name'])): ?>
                                    <span class="badge bg-secondary ms-2 flex-shrink-0">
                                        <?= htmlspecialchars($product['category_name']) ?>
                                    </span>
                                <?php endif; ?>
                            </div>
                            <?php if (!empty($product['listed_price'])): ?>
                                <p class="mb-1 product-price">$<?= number_format($product['listed_price'], 2) ?></p>
                            <?php endif; ?>
                            <p class="card-text text-muted" title="<?= htmlspecialchars($product['description']) ?>">
                                <?= nl2br(htmlspecialchars(substr($product['description'], 0, 80))) ?>...
                            </p>
                            <a href="<?= BASE_URL ?>storefront/<?= urlencode($organization_slug) ?>/<?= urlencode($product['receiving_id']) ?>" class="btn btn-outline-primary btn-sm mt-auto">View Details</a>
                        </div>
                        <div class="card-footer bg-white border-top-0 text-muted small">
                            Posted: <?= date('M d, Y', strtotime($product['created_at'])) ?>
                        </div>
                    </div>
                </div>
            <?php endforeach; ?>
        </div>
    <?php endif; ?>
</div>

<script>
document.addEventListener('DOMContentLoaded', function() {
    const searchToggle = document.getElementById('searchToggle');
    const searchContainer = document.getElementById('navbarSearch');
    const searchInput = document.getElementById('searchInput');
    const searchClose = document.getElementById('searchClose');
    
    // Toggle search bar visibility
    searchToggle.addEventListener('click', function() {
        searchContainer.classList.toggle('show');
        if (searchContainer.classList.contains('show')) {
            setTimeout(() => {
                searchInput.focus();
            }, 300);
        }
    });
    
    // Close search bar
    searchClose.addEventListener('click', function() {
        searchContainer.classList.remove('show');
        searchInput.value = '';
        document.querySelectorAll('.product-card-wrapper').forEach(card => {
            card.style.display = '';
        });
    });
    
    // Close search when clicking outside
    document.addEventListener('click', function(event) {
        if (!searchToggle.contains(event.target) && 
            !searchContainer.contains(event.target)) {
            searchContainer.classList.remove('show');
        }
    });
    
    // Close search on Escape key
    document.addEventListener('keydown', function(event) {
        if (event.key === 'Escape' && searchContainer.classList.contains('show')) {
            searchContainer.classList.remove('show');
            searchInput.value = '';
            document.querySelectorAll('.product-card-wrapper').forEach(card => {
                card.style.display = '';
            });
        }
    });
    
    // Search functionality
    searchInput.addEventListener('keyup', function() {
        let query = this.value.toLowerCase();
        document.querySelectorAll('.product-card-wrapper').forEach(card => {
            card.style.display = card.textContent.toLowerCase().includes(query) ? '' : 'none';
        });
    });
    
    // Handle Enter key for search
    searchInput.addEventListener('keydown', function(event) {
        if (event.key === 'Enter') {
            event.preventDefault();
            this.blur();
        }
    });
});
</script>

</body>
</html>