<?php
// views/storefront/manage.php
require_once __DIR__ . '/../../config/config.php';
require_once __DIR__ . '/../../config/db.php';
require_once __DIR__ . '/../../helpers/AuthHelper.php';
require_once __DIR__ . '/../../helpers/RoleHelper.php';

// UPDATED: Require permission to view storefront listings
AuthHelper::requirePermission('publish_to_storefront');

$user_id = $_SESSION['user_id'];
$organization_id = $_SESSION['organization_id'];

$error = '';
$activeProducts = [];
$inactiveProducts = [];

try {
    // UPDATED: Enhanced security - only fetch products for user's organization WITH payment fields
    $stmt = $pdo->prepare("
        SELECT sp.id, sp.title, sp.description, sp.listed_price, sp.is_active, sp.created_at,
               sp.payment_link, sp.payment_type, sp.receiving_id
        FROM whsale_inventory_pro_storefront_products sp
        WHERE sp.organization_id = ?
        ORDER BY sp.created_at DESC
    ");
    $stmt->execute([$organization_id]);
    $allProducts = $stmt->fetchAll(PDO::FETCH_ASSOC);

    foreach ($allProducts as $product) {
        if ($product['is_active']) {
            $activeProducts[] = $product;
        } else {
            $inactiveProducts[] = $product;
        }
    }
} catch (Exception $e) {
    $error = $e->getMessage();
}

include __DIR__ . '/../partials/head.php';
?>

<div class="container mt-4 mb-5">
    <div class="d-flex align-items-center mb-4">
        <h4 class="mb-0 me-3">Manage My Listings</h4>
        <div class="ms-auto">
            <?= RoleHelper::getRoleBadge() ?>
        </div>
    </div>
    
    <div class="mb-4">
        <!-- UPDATED: Check permission for publishing new listings -->
        <?php if (RoleHelper::hasPermission('publish_to_storefront')): ?>
            <a href="<?= BASE_URL ?>receiving" class="btn btn-sm btn-outline-success" data-permission="publish_to_storefront">
                <i class="bi bi-plus-circle me-1"></i>Publish New Listing
            </a>
            <p class="text-muted small mt-1 mb-0">Tap 'Publish New Listing' to select a receiving log to add to your store.</p>
        <?php else: ?>
            <div class="alert alert-info">
                <i class="fas fa-info-circle me-2"></i>
                You don't have permission to publish new listings. Contact your administrator to get access.
            </div>
        <?php endif; ?>
    </div>

    <?php if ($error): ?>
        <div class="alert alert-danger">
            <i class="fas fa-exclamation-circle me-2"></i>
            <?= htmlspecialchars($error) ?>
        </div>
    <?php endif; ?>

    <div class="mb-5">
        <h5 class="mb-3">
            <i class="fas fa-eye me-2"></i>Active Products
            <?php if (!empty($activeProducts)): ?>
                <span class="badge bg-success"><?= count($activeProducts) ?></span>
            <?php endif; ?>
        </h5>
        <?php if (count($activeProducts) === 0): ?>
            <div class="alert alert-info">
                <i class="fas fa-info-circle me-2"></i>
                No active products found.
                <?php if (RoleHelper::hasPermission('publish_to_storefront')): ?>
                    <a href="<?= BASE_URL ?>receiving" class="alert-link">Create your first listing</a>.
                <?php else: ?>
                    Contact your administrator to get permission to publish listings.
                <?php endif; ?>
            </div>
        <?php else: ?>

            <!-- Table for Desktop -->
            <div class="table-responsive d-none d-lg-block">
                <table class="table table-bordered table-sm table-hover bg-white">
                    <thead class="table-light">
                        <tr>
                            <th>Title</th>
                            <th>Description</th>
                            <th>Listed Price</th>
                            <th>Payment</th>
                            <th>Published</th>
                            <th>Actions</th>
                        </tr>
                    </thead>
                    <tbody>
                        <?php foreach ($activeProducts as $product): ?>
                            <tr>
                                <td><?= htmlspecialchars($product['title']) ?></td>
                                <td><?= htmlspecialchars(substr($product['description'], 0, 80)) ?><?= strlen($product['description']) > 80 ? '...' : '' ?></td>
                                <td><?= $product['listed_price'] ? '$' . number_format($product['listed_price'], 2) : '<span class="text-muted">Contact for price</span>' ?></td>
                                <td>
                                    <!-- UPDATED: Payment status indicator -->
                                    <?php if (!empty($product['payment_link'])): ?>
                                        <span class="badge bg-success">
                                            <i class="fas fa-credit-card me-1"></i>
                                            <?= ucfirst($product['payment_type'] ?? 'Active') ?>
                                        </span>
                                    <?php else: ?>
                                        <span class="badge bg-secondary">
                                            <i class="fas fa-envelope me-1"></i>Contact Only
                                        </span>
                                    <?php endif; ?>
                                </td>
                                <td><?= $product['created_at'] ? date('M d, Y', strtotime($product['created_at'])) : '—' ?></td>
                                <td>
                                    <div class="d-flex gap-1 flex-wrap">
                                        <!-- UPDATED: Edit button with permission check -->
                                        <?php if (RoleHelper::hasPermission('edit_storefront_listings')): ?>
                                            <a href="<?= BASE_URL ?>storefront/manage/edit?id=<?= urlencode($product['id']) ?>" 
                                               class="btn btn-sm btn-outline-primary" data-permission="edit_storefront_listings">
                                                <i class="fas fa-edit me-1"></i>Edit
                                            </a>
                                        <?php endif; ?>
                                        
                                        <!-- UPDATED: Remove button with permission check -->
                                        <?php if (RoleHelper::hasPermission('remove_storefront_listings')): ?>
                                            <form method="POST" action="<?= BASE_URL ?>storefront/manage/delete" 
                                                  onsubmit="return confirm('Are you sure you want to remove this product from your active store listings? You can add it back later by reactivating it from the inactive products list if you change your mind.');"
                                                  class="d-inline">
                                                <input type="hidden" name="product_id" value="<?= $product['id'] ?>">
                                                <input type="hidden" name="action" value="delete">
                                                <button class="btn btn-sm btn-outline-danger" type="submit" data-permission="remove_storefront_listings">
                                                    <i class="fas fa-eye-slash me-1"></i>Remove
                                                </button>
                                            </form>
                                        <?php endif; ?>
                                    </div>
                                </td>
                            </tr>
                        <?php endforeach; ?>
                    </tbody>
                </table>
            </div>

            <!-- Cards for Mobile -->
            <div class="d-block d-lg-none">
                <?php foreach ($activeProducts as $product): ?>
                    <div class="card mb-3 shadow-sm">
                        <div class="card-body">
                            <h6 class="card-title mb-2"><?= htmlspecialchars($product['title']) ?></h6>
                            <p class="mb-2"><?= htmlspecialchars($product['description']) ?></p>
                            <p class="mb-1"><strong>Price:</strong> <?= $product['listed_price'] ? '$' . number_format($product['listed_price'], 2) : '<span class="text-muted">Contact for price</span>' ?></p>
                            
                            <!-- UPDATED: Payment status for mobile -->
                            <p class="mb-1"><strong>Payment:</strong> 
                                <?php if (!empty($product['payment_link'])): ?>
                                    <span class="badge bg-success">
                                        <i class="fas fa-credit-card me-1"></i>
                                        <?= ucfirst($product['payment_type'] ?? 'Active') ?>
                                    </span>
                                <?php else: ?>
                                    <span class="badge bg-secondary">
                                        <i class="fas fa-envelope me-1"></i>Contact Only
                                    </span>
                                <?php endif; ?>
                            </p>
                            
                            <p class="mb-3"><strong>Published:</strong> <?= $product['created_at'] ? date('M d, Y', strtotime($product['created_at'])) : '—' ?></p>
                            
                            <!-- UPDATED: Mobile action buttons with permission checks -->
                            <div class="d-flex flex-wrap gap-2">
                                <?php if (RoleHelper::hasPermission('edit_storefront_listings')): ?>
                                    <a href="<?= BASE_URL ?>storefront/manage/edit?id=<?= urlencode($product['id']) ?>" 
                                       class="btn btn-sm btn-outline-primary flex-fill" data-permission="edit_storefront_listings">
                                        <i class="fas fa-edit me-1"></i>Edit
                                    </a>
                                <?php endif; ?>
                                
                                <?php if (RoleHelper::hasPermission('remove_storefront_listings')): ?>
                                    <form method="POST" action="<?= BASE_URL ?>storefront/manage/delete" 
                                          onsubmit="return confirm('Are you sure you want to remove this product from your active store listings? You can add it back later by reactivating it from the inactive products list if you change your mind.');"
                                          class="flex-fill">
                                        <input type="hidden" name="product_id" value="<?= $product['id'] ?>">
                                        <input type="hidden" name="action" value="delete">
                                        <button class="btn btn-sm btn-outline-danger w-100" type="submit" data-permission="remove_storefront_listings">
                                            <i class="fas fa-eye-slash me-1"></i>Remove
                                        </button>
                                    </form>
                                <?php endif; ?>
                            </div>
                        </div>
                    </div>
                <?php endforeach; ?>
            </div>

        <?php endif; ?>
    </div>

    <div>
        <h5 class="mb-3">
            <i class="fas fa-eye-slash me-2"></i>Inactive Products
            <?php if (!empty($inactiveProducts)): ?>
                <span class="badge bg-secondary"><?= count($inactiveProducts) ?></span>
            <?php endif; ?>
        </h5>
        <?php if (count($inactiveProducts) === 0): ?>
            <div class="alert alert-secondary">
                <i class="fas fa-info-circle me-2"></i>
                No inactive products found.
            </div>
        <?php else: ?>

            <!-- Table for Desktop -->
            <div class="table-responsive d-none d-lg-block">
                <table class="table table-bordered table-sm table-hover bg-white">
                    <thead class="table-light">
                        <tr>
                            <th>Title</th>
                            <th>Description</th>
                            <th>Listed Price</th>
                            <th>Payment</th>
                            <th>Created</th>
                            <th>Actions</th>
                        </tr>
                    </thead>
                    <tbody>
                        <?php foreach ($inactiveProducts as $product): ?>
                            <tr>
                                <td><?= htmlspecialchars($product['title']) ?></td>
                                <td><?= htmlspecialchars(substr($product['description'], 0, 80)) ?><?= strlen($product['description']) > 80 ? '...' : '' ?></td>
                                <td><?= $product['listed_price'] ? '$' . number_format($product['listed_price'], 2) : '<span class="text-muted">Contact for price</span>' ?></td>
                                <td>
                                    <!-- UPDATED: Payment status indicator for inactive products -->
                                    <?php if (!empty($product['payment_link'])): ?>
                                        <span class="badge bg-success">
                                            <i class="fas fa-credit-card me-1"></i>
                                            <?= ucfirst($product['payment_type'] ?? 'Active') ?>
                                        </span>
                                    <?php else: ?>
                                        <span class="badge bg-secondary">
                                            <i class="fas fa-envelope me-1"></i>Contact Only
                                        </span>
                                    <?php endif; ?>
                                </td>
                                <td><?= date('M d, Y', strtotime($product['created_at'])) ?></td>
                                <td>
                                    <div class="d-flex gap-1 flex-wrap">
                                        <!-- UPDATED: Edit button with permission check -->
                                        <?php if (RoleHelper::hasPermission('edit_storefront_listings')): ?>
                                            <a href="<?= BASE_URL ?>storefront/manage/edit?id=<?= urlencode($product['id']) ?>" 
                                               class="btn btn-sm btn-outline-primary" data-permission="edit_storefront_listings">
                                                <i class="fas fa-edit me-1"></i>Edit
                                            </a>
                                        <?php endif; ?>
                                        
                                        <!-- UPDATED: Reactivate button with permission check -->
                                        <?php if (RoleHelper::hasPermission('edit_storefront_listings')): ?>
                                            <form method="POST" action="<?= BASE_URL ?>storefront/manage/delete" 
                                                  onsubmit="return confirm('Reactivate this product on your store? It will immediately be available for customers to view.');"
                                                  class="d-inline">
                                                <input type="hidden" name="product_id" value="<?= $product['id'] ?>">
                                                <input type="hidden" name="action" value="reactivate">
                                                <button class="btn btn-sm btn-outline-success" type="submit" data-permission="edit_storefront_listings">
                                                    <i class="fas fa-eye me-1"></i>Reactivate
                                                </button>
                                            </form>
                                        <?php endif; ?>
                                        
                                        <!-- UPDATED: Delete button with permission check -->
                                        <?php if (RoleHelper::hasPermission('remove_storefront_listings')): ?>
                                            <form method="POST" action="<?= BASE_URL ?>storefront/manage/delete" 
                                                  onsubmit="return confirm('Permanently delete this product from your store? This will NOT delete the product from your internal inventory, only from your store listings. This cannot be undone.');"
                                                  class="d-inline">
                                                <input type="hidden" name="product_id" value="<?= $product['id'] ?>">
                                                <input type="hidden" name="action" value="hard_delete">
                                                <button class="btn btn-sm btn-outline-danger" type="submit" data-permission="remove_storefront_listings">
                                                    <i class="fas fa-trash me-1"></i>Delete
                                                </button>
                                            </form>
                                        <?php endif; ?>
                                    </div>
                                </td>
                            </tr>
                        <?php endforeach; ?>
                    </tbody>
                </table>
            </div>

            <!-- Cards for Mobile -->
            <div class="d-block d-lg-none">
                <?php foreach ($inactiveProducts as $product): ?>
                    <div class="card mb-3 shadow-sm">
                        <div class="card-body">
                            <h6 class="card-title mb-2"><?= htmlspecialchars($product['title']) ?></h6>
                            <p class="mb-2"><?= htmlspecialchars($product['description']) ?></p>
                            <p class="mb-1"><strong>Price:</strong> <?= $product['listed_price'] ? '$' . number_format($product['listed_price'], 2) : '<span class="text-muted">Contact for price</span>' ?></p>
                            
                            <!-- UPDATED: Payment status for mobile inactive products -->
                            <p class="mb-1"><strong>Payment:</strong> 
                                <?php if (!empty($product['payment_link'])): ?>
                                    <span class="badge bg-success">
                                        <i class="fas fa-credit-card me-1"></i>
                                        <?= ucfirst($product['payment_type'] ?? 'Active') ?>
                                    </span>
                                <?php else: ?>
                                    <span class="badge bg-secondary">
                                        <i class="fas fa-envelope me-1"></i>Contact Only
                                    </span>
                                <?php endif; ?>
                            </p>
                            
                            <p class="mb-3"><strong>Created:</strong> <?= date('M d, Y', strtotime($product['created_at'])) ?></p>
                            
                            <!-- UPDATED: Mobile action buttons with permission checks -->
                            <div class="d-flex flex-wrap gap-2">
                                <?php if (RoleHelper::hasPermission('edit_storefront_listings')): ?>
                                    <a href="<?= BASE_URL ?>storefront/manage/edit?id=<?= urlencode($product['id']) ?>" 
                                       class="btn btn-sm btn-outline-primary" data-permission="edit_storefront_listings">
                                        <i class="fas fa-edit me-1"></i>Edit
                                    </a>
                                    
                                    <form method="POST" action="<?= BASE_URL ?>storefront/manage/delete" 
                                          onsubmit="return confirm('Reactivate this product on your store? It will immediately be available for customers to view.');"
                                          class="d-inline">
                                        <input type="hidden" name="product_id" value="<?= $product['id'] ?>">
                                        <input type="hidden" name="action" value="reactivate">
                                        <button class="btn btn-sm btn-outline-success" type="submit" data-permission="edit_storefront_listings">
                                            <i class="fas fa-eye me-1"></i>Reactivate
                                        </button>
                                    </form>
                                <?php endif; ?>
                                
                                <?php if (RoleHelper::hasPermission('remove_storefront_listings')): ?>
                                    <form method="POST" action="<?= BASE_URL ?>storefront/manage/delete" 
                                          onsubmit="return confirm('Permanently delete this product from your store? This will NOT delete the product from your internal inventory, only from your store listings. This cannot be undone.');"
                                          class="d-inline">
                                        <input type="hidden" name="product_id" value="<?= $product['id'] ?>">
                                        <input type="hidden" name="action" value="hard_delete">
                                        <button class="btn btn-sm btn-outline-danger" type="submit" data-permission="remove_storefront_listings">
                                            <i class="fas fa-trash me-1"></i>Delete
                                        </button>
                                    </form>
                                <?php endif; ?>
                            </div>
                        </div>
                    </div>
                <?php endforeach; ?>
            </div>

        <?php endif; ?>
    </div>

    <!-- Navigation -->
    <div class="mt-4 pt-3 border-top">
        <div class="d-flex flex-wrap gap-2 justify-content-between align-items-center">
            <a href="<?= BASE_URL ?>dashboard" class="btn btn-outline-secondary">
                <i class="fas fa-arrow-left me-1"></i>Back to Dashboard
            </a>
            
            <!-- UPDATED: Branding management with permission check -->
            <?php if (RoleHelper::hasPermission('manage_storefront_branding')): ?>
                <a href="<?= BASE_URL ?>storefront/profile/edit" class="btn btn-outline-info" data-permission="manage_storefront_branding">
                    <i class="fas fa-palette me-1"></i>Customize Storefront
                </a>
            <?php endif; ?>
        </div>
    </div>
</div>

<!-- UPDATED: Custom CSS for permission elements and payment indicators -->
<style>
/* Permission-protected elements styling */
[data-permission].permission-denied {
    opacity: 0.6;
    pointer-events: none;
    position: relative;
}

[data-permission].permission-denied::after {
    content: "\f023";
    font-family: "Font Awesome 5 Free";
    font-weight: 900;
    position: absolute;
    top: 50%;
    right: 8px;
    transform: translateY(-50%);
    color: #dc3545;
    font-size: 12px;
}

/* Payment status badges */
.badge.bg-success {
    background-color: #198754 !important;
}

.badge.bg-secondary {
    background-color: #6c757d !important;
}

/* Mobile responsiveness improvements */
@media (max-width: 768px) {
    .d-flex.gap-2.flex-wrap {
        gap: 0.5rem !important;
    }
    
    .btn-sm {
        font-size: 0.775rem;
        padding: 0.25rem 0.5rem;
    }
    
    .flex-fill {
        flex: 1;
    }
    
    .d-flex.flex-wrap.gap-2.justify-content-between {
        flex-direction: column;
        gap: 1rem !important;
    }
}

/* Desktop action buttons */
@media (min-width: 992px) {
    .table td .d-flex {
        justify-content: flex-start;
    }
}

/* Table hover effects */
.table-hover tbody tr:hover {
    background-color: rgba(0, 0, 0, 0.025);
}

/* Card hover effects */
.card:hover {
    transform: translateY(-1px);
    box-shadow: 0 4px 8px rgba(0, 0, 0, 0.1);
    transition: all 0.2s ease;
}

/* Badge styling */
.badge {
    font-size: 0.75em;
    font-weight: 500;
}

/* Alert styling improvements */
.alert {
    border: none;
    border-radius: 8px;
}

.alert-info {
    background-color: #e3f2fd;
    color: #1976d2;
}

.alert-secondary {
    background-color: #f5f5f5;
    color: #616161;
}
</style>

<?php include __DIR__ . '/../partials/footer.php'; ?>