<?php
require_once __DIR__ . '/../../config/config.php';
require_once __DIR__ . '/../../helpers/AuthHelper.php';
require_once __DIR__ . '/../../helpers/RoleHelper.php';

// UPDATED: Require specific permission for publishing to storefront
AuthHelper::requirePermission('publish_to_storefront');

$receiving_id = $_GET['receiving_id'] ?? null;
if (!$receiving_id || !is_numeric($receiving_id)) {
    echo "<div class='alert alert-danger mt-4 text-center'>Invalid Receiving ID</div>";
    exit;
}

$error = '';
$log = null;
$photos = [];
$organization_id = $_SESSION['organization_id'];

try {
    // UPDATED: Enhanced security - verify receiving log belongs to user's organization
    $stmt = $pdo->prepare("
        SELECT r.*, c.category_name 
        FROM whsale_inventory_pro_receiving_log r
        LEFT JOIN whsale_inventory_pro_categories c ON r.category_id = c.id
        WHERE r.id = ? AND r.organization_id = ?
    ");
    $stmt->execute([$receiving_id, $organization_id]);
    $log = $stmt->fetch();
    $stmt->closeCursor();

    if (!$log) {
        throw new Exception("Receiving log not found or you don't have permission to access it.");
    }

    // UPDATED: Enhanced security - verify photos belong to user's organization
    $stmt = $pdo->prepare("
        SELECT rp.* FROM whsale_inventory_pro_receiving_photos rp
        JOIN whsale_inventory_pro_receiving_log r ON rp.receiving_id = r.id
        WHERE rp.receiving_id = ? AND r.organization_id = ?
        ORDER BY rp.uploaded_at DESC
    ");
    $stmt->execute([$receiving_id, $organization_id]);
    $photos = $stmt->fetchAll();
    $stmt->closeCursor();
} catch (Exception $e) {
    $error = $e->getMessage();
}
?>

<?php include __DIR__ . '/../partials/head.php'; ?>

<div class="container mt-4 mb-5">
    <div class="row justify-content-center">
        <div class="col-12 col-lg-8">
            <div class="d-flex align-items-center mb-3">
                <h4 class="mb-0 me-3">
                    <i class="fas fa-store me-2"></i>Preview Storefront Listing
                </h4>
                <div class="ms-auto">
                    <?= RoleHelper::getRoleBadge() ?>
                </div>
            </div>

            <?php if ($error): ?>
                <div class="alert alert-danger">
                    <i class="fas fa-exclamation-circle me-2"></i>
                    <?= htmlspecialchars($error) ?>
                </div>
            <?php elseif ($log): ?>
                
                <!-- Receiving Log Preview -->
                <div class="card mb-4 shadow-sm border-0">
                    <div class="card-header bg-light">
                        <h6 class="mb-0">
                            <i class="fas fa-truck me-2"></i>Receiving Log Details
                        </h6>
                    </div>
                    <div class="card-body">
                        <div class="row">
                            <div class="col-md-6">
                                <h5 class="mb-3"><?= htmlspecialchars($log['vendor_name']) ?> — <?= htmlspecialchars($log['po_number']) ?></h5>
                                <p><strong>Date Received:</strong> <?= date('M d, Y', strtotime($log['delivery_date'])) ?></p>
                                <p><strong>Created:</strong> <?= date('M d, Y', strtotime($log['created_at'])) ?></p>
                            </div>
                            <div class="col-md-6">
                                <p><strong>Category:</strong> 
                                    <?php if (!empty($log['category_name'])): ?>
                                        <span class="badge bg-secondary">
                                            <?= htmlspecialchars($log['category_name']) ?>
                                        </span>
                                    <?php else: ?>
                                        <span class="text-muted">Uncategorized</span>
                                    <?php endif; ?>
                                </p>
                            </div>
                        </div>
                        <?php if (!empty($log['notes'])): ?>
                            <div class="mt-3 pt-3 border-top">
                                <p><strong>Notes:</strong><br><?= nl2br(htmlspecialchars($log['notes'])) ?></p>
                            </div>
                        <?php endif; ?>
                    </div>
                </div>

                <!-- Photos Preview -->
                <?php if (!empty($photos)): ?>
                    <div class="card mb-4 border-0 shadow-sm">
                        <div class="card-header bg-light">
                            <h6 class="mb-0">
                                <i class="fas fa-images me-2"></i>Product Photos (<?= count($photos) ?>)
                            </h6>
                        </div>
                        <div class="card-body">
                            <div class="row g-3">
                                <?php foreach ($photos as $photo): ?>
                                    <div class="col-6 col-md-4 col-lg-3">
                                        <div class="border rounded shadow-sm p-2 bg-light text-center">
                                            <img src="<?= BASE_URL ?>public/uploads/receiving/<?= htmlspecialchars($photo['file_path']) ?>" 
                                                 class="img-fluid rounded mb-2" style="max-height: 180px; object-fit: cover;">
                                            <?php if (!empty($photo['caption'])): ?>
                                                <p class="text-muted small mb-0"><?= htmlspecialchars($photo['caption']) ?></p>
                                            <?php endif; ?>
                                        </div>
                                    </div>
                                <?php endforeach; ?>
                            </div>
                        </div>
                    </div>
                <?php endif; ?>

                <!-- Storefront Listing Form -->
                <div class="card shadow-sm border-0">
                    <div class="card-header bg-primary text-white">
                        <h6 class="mb-0">
                            <i class="fas fa-edit me-2"></i>Create Storefront Listing
                        </h6>
                    </div>
                    <div class="card-body">
                        <form action="<?= BASE_URL ?>storefront/publish" method="POST">
                            <input type="hidden" name="receiving_id" value="<?= htmlspecialchars($receiving_id) ?>">
                            
                            <div class="mb-3">
                                <label for="title" class="form-label">
                                    <i class="fas fa-heading me-1"></i>Listing Title <span class="text-danger">*</span>
                                </label>
                                <input type="text" class="form-control" id="title" name="title" required
                                       placeholder="Enter an attractive title for your product listing">
                                <div class="form-text">This will be the main headline customers see</div>
                            </div>

                            <div class="mb-3">
                                <label for="description" class="form-label">
                                    <i class="fas fa-align-left me-1"></i>Listing Description <span class="text-danger">*</span>
                                </label>
                                <textarea class="form-control" id="description" name="description" rows="4" required
                                          placeholder="Describe the product, condition, quantity, and any important details..."></textarea>
                                <div class="form-text">Provide detailed information to help customers make purchasing decisions</div>
                            </div>
                            
                            <div class="row">
                                <div class="col-md-6 mb-3">
                                    <label for="listed_price" class="form-label">
                                        <i class="fas fa-dollar-sign me-1"></i>Listing Price
                                    </label>
                                    <div class="input-group">
                                        <span class="input-group-text">$</span>
                                        <input type="number" step="0.01" name="listed_price" id="listed_price" 
                                               class="form-control" placeholder="0.00" min="0">
                                    </div>
                                    <div class="form-text">Leave blank if price on request</div>
                                </div>
                                
                                <div class="col-md-6 mb-3">
                                    <label for="storefront_category" class="form-label">
                                        <i class="fas fa-tag me-1"></i>Storefront Category
                                    </label>
                                    <div class="category-selector">
                                        <!-- Existing Category Dropdown -->
                                        <select name="category_id" id="categorySelect" class="form-select mb-2">
                                            <option value="">Select category (optional)</option>
                                            <?php 
                                            // UPDATED: Enhanced security - only fetch categories for user's organization
                                            try {
                                                $catStmt = $pdo->prepare("SELECT id, category_name FROM whsale_inventory_pro_categories WHERE organization_id = ? ORDER BY category_name ASC");
                                                $catStmt->execute([$organization_id]);
                                                $allCategories = $catStmt->fetchAll(PDO::FETCH_ASSOC);
                                                
                                                foreach ($allCategories as $category): ?>
                                                    <option value="<?= $category['id'] ?>" 
                                                            <?= (!empty($log['category_id']) && $log['category_id'] == $category['id']) ? 'selected' : '' ?>>
                                                        <?= htmlspecialchars($category['category_name']) ?>
                                                    </option>
                                                <?php endforeach;
                                            } catch (Exception $e) {
                                                error_log("Error fetching categories: " . $e->getMessage());
                                            }
                                            ?>
                                        </select>
                                        
                                        <!-- OR divider -->
                                        <div class="text-center text-muted small mb-2">
                                            <span class="px-2 bg-white">OR</span>
                                            <hr class="mt-0" style="margin-top: -12px; z-index: -1;">
                                        </div>
                                        
                                        <!-- New Category Input -->
                                        <div class="input-group">
                                            <input type="text" name="new_category" id="newCategoryInput" class="form-control" 
                                                   placeholder="Create new category..." maxlength="100">
                                            <button type="button" class="btn btn-outline-secondary" id="clearCategoryBtn" 
                                                    onclick="clearCategorySelection()" title="Clear selection">
                                                <i class="fas fa-times"></i>
                                            </button>
                                        </div>
                                    </div>
                                    <div class="form-text">
                                        <i class="fas fa-info-circle me-1"></i>
                                        <?php if (!empty($log['category_name'])): ?>
                                            <strong>Receiving log category:</strong> <?= htmlspecialchars($log['category_name']) ?><br>
                                        <?php endif; ?>
                                        Choose a category for your storefront (can be different from receiving log)
                                    </div>
                                </div>
                            </div>

                            <div class="d-flex gap-2 justify-content-end mt-4">
                                <a href="<?= BASE_URL ?>receiving/view?id=<?= urlencode($receiving_id) ?>" 
                                   class="btn btn-outline-secondary">
                                    <i class="fas fa-arrow-left me-1"></i>Back to Receiving Log
                                </a>
                                <button type="submit" class="btn btn-primary">
                                    <i class="fas fa-upload me-1"></i>Publish to Storefront
                                </button>
                            </div>
                        </form>
                    </div>
                </div>

            <?php endif; ?>
        </div>
    </div>
</div>

<!-- Custom CSS for Category Selector -->
<style>
.category-selector {
    position: relative;
}

.category-selector .form-select:focus,
.category-selector .form-control:focus {
    border-color: #0d6efd;
    box-shadow: 0 0 0 0.2rem rgba(13, 110, 253, 0.25);
}

.category-selector hr {
    position: relative;
    border-color: #dee2e6;
}

.category-selector .text-muted span {
    position: relative;
    z-index: 1;
}

#clearCategoryBtn {
    border-left: none;
}

.input-group .form-control:focus + .btn {
    border-color: #0d6efd;
    box-shadow: 0 0 0 0.2rem rgba(13, 110, 253, 0.25);
}

/* Mobile responsiveness improvements */
@media (max-width: 768px) {
    .d-flex.gap-2 {
        flex-direction: column;
        gap: 0.75rem !important;
    }
    
    .btn {
        text-align: center;
    }
}
</style>

<!-- Enhanced JavaScript -->
<script>
// Handle category selection logic
document.addEventListener('DOMContentLoaded', function() {
    const categorySelect = document.getElementById('categorySelect');
    const newCategoryInput = document.getElementById('newCategoryInput');
    
    // When user selects an existing category, clear the new category input
    categorySelect.addEventListener('change', function() {
        if (this.value) {
            newCategoryInput.value = '';
        }
    });
    
    // When user types in new category, clear the existing category selection
    newCategoryInput.addEventListener('input', function() {
        if (this.value) {
            categorySelect.value = '';
        }
    });
});

// Clear both category selections
function clearCategorySelection() {
    document.getElementById('categorySelect').value = '';
    document.getElementById('newCategoryInput').value = '';
}
</script>

<?php include __DIR__ . '/../partials/footer.php'; ?>